@@ -32,6 +32,7 @@
 #define EDJE_1_23_SUPPORTED " -DEFL_VERSION_1_23=1 "
 #define EDJE_1_24_SUPPORTED " -DEFL_VERSION_1_24=1 "
 #define EDJE_1_25_SUPPORTED " -DEFL_VERSION_1_25=1 "
+#define EDJE_1_26_SUPPORTED " -DEFL_VERSION_1_26=1 "
 
 #define EDJE_CC_EFL_VERSION_SUPPORTED \
   EDJE_1_18_SUPPORTED                 \
@@ -41,7 +42,8 @@
   EDJE_1_22_SUPPORTED                 \
   EDJE_1_23_SUPPORTED                 \
   EDJE_1_24_SUPPORTED                 \
-  EDJE_1_25_SUPPORTED
+  EDJE_1_25_SUPPORTED                 \
+  EDJE_1_26_SUPPORTED
 
 static void        new_object(void);
 static void        new_statement(void);
