@@ -18,6 +18,8 @@
 using System;
 using System.Runtime.InteropServices;
 using System.ComponentModel;
+using System.Diagnostics.CodeAnalysis;
+using System.Diagnostics.Contracts;
 
 using static eldbus.EldbusMessageNativeFunctions;
 
@@ -41,7 +43,7 @@ public static class Timeout
 /// <para>Since EFL 1.23.</para>
 /// </summary>
 [StructLayout(LayoutKind.Sequential)]
-public struct ObjectPath
+public struct ObjectPath : IEquatable<ObjectPath>
 {
     /// <summary>
     /// The string of the path.
@@ -64,20 +66,71 @@ public struct ObjectPath
     /// <para>Since EFL 1.23.</para>
     /// </summary>
     /// <param name="str">The string of the path.</param>
-    public static implicit operator ObjectPath(string str)
-    {
-        return new ObjectPath(str);
-    }
+    public static implicit operator ObjectPath(string str) => FromString(str);
+
+    /// <summary>
+    ///   Converts a <see cref="string" /> to a <see cref="ObjectPath" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="str">The <see cref="string" /> of the path.</param>
+    public static ObjectPath FromString(string str) => new ObjectPath(str);
 
     /// <summary>
     /// Conversion operator of string from ObjectPath.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
     /// <param name="path">The ObjectPath to be converted.</param>
-    public static implicit operator string(ObjectPath path)
-    {
-        return path.value;
-    }
+    public static implicit operator string(ObjectPath path) => ToString(path);
+
+    /// <summary>
+    /// Converts a <see cref="ObjectPath" /> to a <see cref="string" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="path">The ObjectPath to be converted.</param>
+    public static string ToString(ObjectPath path) => path.value;
+
+    /// <summary>
+    ///   Gets a hash for <see cref="ObjectPath" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <returns>A hash code.</returns>
+    public override int GetHashCode() => value.GetHashCode(StringComparison.Ordinal);
+
+    /// <summary>Returns whether this <see cref="ObjectPath" />
+    /// is equal to the given <see cref="object" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="other">The <see cref="object" /> to be compared to.</param>
+    /// <returns><c>true</c> if is equal to <c>other</c>.</returns>
+    public override bool Equals(object other)
+        => (!(other is ObjectPath)) ? false : Equals((ObjectPath)other);
+
+    /// <summary>Returns whether this <see cref="ObjectPath" /> is equal
+    /// to the given <see cref="ObjectPath" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="other">The <see cref="ObjectPath" /> to be compared to.</param>
+    /// <returns><c>true</c> if is equal to <c>other</c>.</returns>
+    public bool Equals(ObjectPath other) => value == other.value;
+
+    /// <summary>Returns whether <c>lhs</c> is equal to <c>rhs</c>.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="lhs">The left hand side of the operator.</param>
+    /// <param name="rhs">The right hand side of the operator.</param>
+    /// <returns><c>true</c> if <c>lhs</c> is equal
+    /// to <c>rhs</c>.</returns>
+    public static bool operator==(ObjectPath lhs, ObjectPath rhs) => lhs.Equals(rhs);
+
+    /// <summary>Returns whether <c>lhs</c> is not equal to <c>rhs</c>.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="lhs">The left hand side of the operator.</param>
+    /// <param name="rhs">The right hand side of the operator.</param>
+    /// <returns><c>true</c> if <c>lhs</c> is not equal
+    /// to <c>rhs</c>.</returns>
+    public static bool operator!=(ObjectPath lhs, ObjectPath rhs) => !(lhs == rhs);
+
 }
 
 /// <summary>
@@ -85,7 +138,7 @@ public struct ObjectPath
 /// <para>Since EFL 1.23.</para>
 /// </summary>
 [StructLayout(LayoutKind.Sequential)]
-public struct SignatureString
+public struct SignatureString : IEquatable<SignatureString>
 {
     /// <summary>
     /// The string of the signature.
@@ -109,9 +162,15 @@ public struct SignatureString
     /// </summary>
     /// <param name="str">The string of the signature.</param>
     public static implicit operator SignatureString(string str)
-    {
-        return new SignatureString(str);
-    }
+        => FromString(str);
+
+    /// <summary>
+    /// Converts a <see cref="string" /> to a <see cref="SignatureString" />
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="str">The string of the signature.</param>
+    public static SignatureString FromString(string str)
+        => new SignatureString(str);
 
     /// <summary>
     /// Conversion operator of string from SignatureString.
@@ -119,9 +178,51 @@ public struct SignatureString
     /// </summary>
     /// <param name="sig">The SignatureString to be conversion.</param>
     public static implicit operator string(SignatureString sig)
-    {
-        return sig.value;
-    }
+        => ToString(sig);
+
+    public static string ToString(SignatureString sig) => sig.value;
+
+    /// <summary>
+    ///   Gets a hash for <see cref="SignatureString" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <returns>A hash code.</returns>
+    public override int GetHashCode() => value.GetHashCode(StringComparison.Ordinal);
+
+    /// <summary>Returns whether this <see cref="SignatureString" />
+    /// is equal to the given <see cref="object" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="other">The <see cref="object" /> to be compared to.</param>
+    /// <returns><c>true</c> if is equal to <c>other</c>.</returns>
+    public override bool Equals(object other)
+        => (!(other is SignatureString)) ? false : Equals((SignatureString)other);
+
+    /// <summary>Returns whether this <see cref="SignatureString" /> is equal
+    /// to the given <see cref="SignatureString" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="other">The <see cref="SignatureString" /> to be compared to.</param>
+    /// <returns><c>true</c> if is equal to <c>other</c>.</returns>
+    public bool Equals(SignatureString other) => value == other.value;
+
+    /// <summary>Returns whether <c>lhs</c> is equal to <c>rhs</c>.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="lhs">The left hand side of the operator.</param>
+    /// <param name="rhs">The right hand side of the operator.</param>
+    /// <returns><c>true</c> if <c>lhs</c> is equal
+    /// to <c>rhs</c>.</returns>
+    public static bool operator==(SignatureString lhs, SignatureString rhs) => lhs.Equals(rhs);
+
+    /// <summary>Returns whether <c>lhs</c> is not equal to <c>rhs</c>.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="lhs">The left hand side of the operator.</param>
+    /// <param name="rhs">The right hand side of the operator.</param>
+    /// <returns><c>true</c> if <c>lhs</c> is not equal
+    /// to <c>rhs</c>.</returns>
+    public static bool operator!=(SignatureString lhs, SignatureString rhs) => !(lhs == rhs);
 }
 
 /// <summary>
@@ -129,7 +230,7 @@ public struct SignatureString
 /// <para>Since EFL 1.23.</para>
 /// </summary>
 [StructLayout(LayoutKind.Sequential)]
-public struct UnixFd
+public struct UnixFd : IEquatable<UnixFd>
 {
     /// <summary>
     /// The value of the file descriptor.
@@ -152,22 +253,71 @@ public struct UnixFd
     /// <para>Since EFL 1.23.</para>
     /// </summary>
     /// <param name="fd">The file descriptor.</param>
-    public static implicit operator UnixFd(Int32 fd)
-    {
-        return new UnixFd(fd);
-    }
+    public static implicit operator UnixFd(Int32 fd) => FromInt32(fd);
+
+    /// <summary>
+    /// Converts a <see cref="Int32" /> to a <see cref="UnixFd" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="fd">The file descriptor.</param>
+    public static UnixFd FromInt32(Int32 fd) => new UnixFd(fd);
 
     /// <summary>
     /// Conversion operator of Int32 from UnixFd.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
     /// <param name="unix_fd">The UnixFd to be converted.</param>
-    public static implicit operator Int32(UnixFd unix_fd)
-    {
-        return unix_fd.value;
-    }
-}
+    public static implicit operator Int32(UnixFd unix_fd) => ToInt32(unix_fd);
 
+    /// <summary>
+    ///   Converts a <see cref="UnixFd" /> to a <see cref="Int32" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="unix_fd">The <see cref="UnixFd" /> to be converted.</param>
+    public static Int32 ToInt32(UnixFd unix_fd) => unix_fd.value;
+
+    /// <summary>
+    ///   Gets a hash for <see cref="UnixFd" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <returns>A hash code.</returns>
+    public override int GetHashCode() => value.GetHashCode();
+
+    /// <summary>Returns whether this <see cref="UnixFd" />
+    /// is equal to the given <see cref="object" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="other">The <see cref="object" /> to be compared to.</param>
+    /// <returns><c>true</c> if is equal to <c>other</c>.</returns>
+    public override bool Equals(object other)
+        => (!(other is UnixFd)) ? false : Equals((UnixFd)other);
+
+    /// <summary>Returns whether this <see cref="UnixFd" /> is equal
+    /// to the given <see cref="UnixFd" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="other">The <see cref="UnixFd" /> to be compared to.</param>
+    /// <returns><c>true</c> if is equal to <c>other</c>.</returns>
+    public bool Equals(UnixFd other) => value == other.value;
+
+    /// <summary>Returns whether <c>lhs</c> is equal to <c>rhs</c>.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="lhs">The left hand side of the operator.</param>
+    /// <param name="rhs">The right hand side of the operator.</param>
+    /// <returns><c>true</c> if <c>lhs</c> is equal
+    /// to <c>rhs</c>.</returns>
+    public static bool operator==(UnixFd lhs, UnixFd rhs) => lhs.Equals(rhs);
+
+    /// <summary>Returns whether <c>lhs</c> is not equal to <c>rhs</c>.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="lhs">The left hand side of the operator.</param>
+    /// <param name="rhs">The right hand side of the operator.</param>
+    /// <returns><c>true</c> if <c>lhs</c> is not equal
+    /// to <c>rhs</c>.</returns>
+    public static bool operator!=(UnixFd lhs, UnixFd rhs) => !(lhs == rhs);
+}
 /// <summary>
 /// Arguments of EldBus.
 /// <para>Since EFL 1.23.</para>
@@ -178,7 +328,7 @@ public static class Argument
     /// The type of a byte.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class ByteType
+    internal static class ByteType
     {
         /// <summary>
         /// The code of the byte.
@@ -196,7 +346,7 @@ public static class Argument
     /// The type of a boolean
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class BooleanType
+    internal static class BooleanType
     {
         /// <summary>
         /// The code of the boolean.
@@ -214,7 +364,7 @@ public static class Argument
     /// The type of a Int16.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class Int16Type
+    internal static class Int16Type
     {
         /// <summary>
         /// The code of the Int16.
@@ -232,7 +382,7 @@ public static class Argument
     /// The type of an unsigned Int16.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class UInt16Type
+    internal static class UInt16Type
     {
         /// <summary>
         /// The code of the unsigned Int16.
@@ -250,7 +400,7 @@ public static class Argument
     /// The type of a Int32.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class Int32Type
+    internal static class Int32Type
     {
         /// <summary>
         /// The code of the Int32.
@@ -268,7 +418,7 @@ public static class Argument
     /// The type of an unsigned Int32.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class UInt32Type
+    internal static class UInt32Type
     {
         /// <summary>
         /// The code of the unsigned Int32.
@@ -286,7 +436,7 @@ public static class Argument
     /// The type of a Int64.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class Int64Type
+    internal static class Int64Type
     {
         /// <summary>
         /// The code of the Int64.
@@ -304,7 +454,7 @@ public static class Argument
     /// The type of an unsigned Int64.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class UInt64Type
+    internal static class UInt64Type
     {
         /// <summary>
         /// The code of the unsigned Int64.
@@ -322,7 +472,7 @@ public static class Argument
     /// The type of the double.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class DoubleType
+    internal static class DoubleType
     {
         /// <summary>
         /// The code of the double.
@@ -340,7 +490,7 @@ public static class Argument
     /// The type of a string.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class StringType
+    internal static class StringType
     {
         /// <summary>
         /// The code of the string.
@@ -358,7 +508,7 @@ public static class Argument
     /// The type of an object path.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class ObjectPathType
+    internal static class ObjectPathType
     {
         /// <summary>
         /// The code of the object path.
@@ -376,7 +526,7 @@ public static class Argument
     /// The type of a signature.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class SignatureType
+    internal static class SignatureType
     {
         /// <summary>
         /// The code of the signature.
@@ -394,7 +544,7 @@ public static class Argument
     /// The type of a array.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class ArrayType
+    internal static class ArrayType
     {
         /// <summary>
         /// The code of the array.
@@ -412,7 +562,7 @@ public static class Argument
     /// The type of a struct.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class StructType
+    internal static class StructType
     {
         /// <summary>
         /// The code of the struct.
@@ -430,7 +580,7 @@ public static class Argument
     /// The type of a variant.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class VariantType
+    internal static class VariantType
     {
         /// <summary>
         /// The code of the variant.
@@ -448,7 +598,7 @@ public static class Argument
     /// The type of a dictionary.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class DictEntryType
+    internal static class DictEntryType
     {
         /// <summary>
         /// The code of the dictionary.
@@ -466,7 +616,7 @@ public static class Argument
     /// The type of an unix file descriptor.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
-    public static class UnixFdType
+    internal static class UnixFdType
     {
         /// <summary>
         /// The code of unix fd.
@@ -573,9 +723,15 @@ public abstract class BasicMessageArgument
     /// </summary>
     /// <param name="arg">The byte to be converted.</param>
     public static implicit operator BasicMessageArgument(byte arg)
-    {
-        return new ByteMessageArgument(arg);
-    }
+        => FromByte(arg);
+
+    /// <summary>
+    ///   Converts a <see cref="byte" /> to a <see cref="BasicMessageArgument" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="arg">The <see cref="byte" /> to be converted.</param>
+    public static BasicMessageArgument FromByte(byte arg)
+        => new ByteMessageArgument(arg);
 
     /// <summary>
     /// Conversion operator of BasicMessageArgument from bool.
@@ -583,9 +739,15 @@ public abstract class BasicMessageArgument
     /// </summary>
     /// <param name="arg">The bool to be converted.</param>
     public static implicit operator BasicMessageArgument(bool arg)
-    {
-        return new BoolMessageArgument(arg);
-    }
+        => FromBoolean(arg);
+
+    /// <summary>
+    ///   Converts a <see cref="bool" /> to a <see cref="BasicMessageArgument" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="arg">The <see cref="bool" /> to be converted.</param>
+    public static BasicMessageArgument FromBoolean(bool arg)
+        => new BoolMessageArgument(arg);
 
     /// <summary>
     /// Conversion operator of BasicMessageArgument from Int16.
@@ -593,9 +755,15 @@ public abstract class BasicMessageArgument
     /// </summary>
     /// <param name="arg">The int16 to be converted.</param>
     public static implicit operator BasicMessageArgument(Int16 arg)
-    {
-        return new Int16MessageArgument(arg);
-    }
+        => FromInt16(arg);
+
+    /// <summary>
+    ///   Converts a <see cref="Int16" /> to a <see cref="BasicMessageArgument" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="arg">The <see cref="Int16" /> to be converted.</param>
+    public static BasicMessageArgument FromInt16(Int16 arg)
+        => new Int16MessageArgument(arg);
 
     /// <summary>
     /// Conversion operator of BasicMessageArgument from unsigned int16.
@@ -603,9 +771,15 @@ public abstract class BasicMessageArgument
     /// </summary>
     /// <param name="arg">The unsigned int16 to be converted.</param>
     public static implicit operator BasicMessageArgument(UInt16 arg)
-    {
-        return new UInt16MessageArgument(arg);
-    }
+        => FromUInt16(arg);
+
+    /// <summary>
+    ///   Converts a <see cref="UInt16" /> to a <see cref="BasicMessageArgument" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="arg">The <see cref="UInt16" /> to be converted.</param>
+    public static BasicMessageArgument FromUInt16(UInt16 arg)
+        => new UInt16MessageArgument(arg);
 
     /// <summary>
     /// Conversion operator of BasicMessageArgument from int32.
@@ -613,9 +787,15 @@ public abstract class BasicMessageArgument
     /// </summary>
     /// <param name="arg">The int32 to be converted.</param>
     public static implicit operator BasicMessageArgument(Int32 arg)
-    {
-        return new Int32MessageArgument(arg);
-    }
+        => FromInt32(arg);
+
+    /// <summary>
+    ///   Converts a <see cref="Int32" /> to a <see cref="BasicMessageArgument" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="arg">The <see cref="Int32" /> to be converted.</param>
+    public static BasicMessageArgument FromInt32(Int32 arg)
+        => new Int32MessageArgument(arg);
 
     /// <summary>
     /// Conversion operator of BasicMessageArgument from unsigned int32.
@@ -623,9 +803,15 @@ public abstract class BasicMessageArgument
     /// </summary>
     /// <param name="arg">The unsigned int32 to be converted.</param>
     public static implicit operator BasicMessageArgument(UInt32 arg)
-    {
-        return new UInt32MessageArgument(arg);
-    }
+        => FromUInt32(arg);
+
+    /// <summary>
+    ///   Converts a <see cref="UInt32" /> to a <see cref="BasicMessageArgument" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="arg">The <see cref="UInt32" /> to be converted.</param>
+    public static BasicMessageArgument FromUInt32(UInt32 arg)
+        => new UInt32MessageArgument(arg);
 
     /// <summary>
     /// Conversion operator of BasicMessageArgument from int64.
@@ -633,9 +819,15 @@ public abstract class BasicMessageArgument
     /// </summary>
     /// <param name="arg">The int64 to be converted.</param>
     public static implicit operator BasicMessageArgument(Int64 arg)
-    {
-        return new Int64MessageArgument(arg);
-    }
+        => FromInt64(arg);
+
+    /// <summary>
+    ///   Converts a <see cref="Int64" /> to a <see cref="BasicMessageArgument" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="arg">The <see cref="Int64" /> to be converted.</param>
+    public static BasicMessageArgument FromInt64(Int64 arg)
+        => new Int64MessageArgument(arg);
 
     /// <summary>
     /// Conversion operator of BasicMessageArgument from unsigned int64.
@@ -643,9 +835,15 @@ public abstract class BasicMessageArgument
     /// </summary>
     /// <param name="arg">The unsigned int64 to be converted.</param>
     public static implicit operator BasicMessageArgument(UInt64 arg)
-    {
-        return new UInt64MessageArgument(arg);
-    }
+        => FromUInt64(arg);
+
+    /// <summary>
+    ///   Converts a <see cref="UInt64" /> to a <see cref="BasicMessageArgument" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="arg">The <see cref="UInt64" /> to be converted.</param>
+    public static BasicMessageArgument FromUInt64(UInt64 arg)
+        => new UInt64MessageArgument(arg);
 
     /// <summary>
     /// Conversion operator of BasicMessageArgument from string.
@@ -653,9 +851,15 @@ public abstract class BasicMessageArgument
     /// </summary>
     /// <param name="arg">the string to be converted.</param>
     public static implicit operator BasicMessageArgument(string arg)
-    {
-        return new StringMessageArgument(arg);
-    }
+        => FromString(arg);
+
+    /// <summary>
+    ///   Converts a <see cref="string" /> to a <see cref="BasicMessageArgument" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="arg">The <see cref="string" /> to be converted.</param>
+    public static BasicMessageArgument FromString(string arg)
+        => new StringMessageArgument(arg);
 
     /// <summary>
     /// Conversion operator of BasicMessageArgument from signature.
@@ -663,9 +867,15 @@ public abstract class BasicMessageArgument
     /// </summary>
     /// <param name="arg">The signature to be converted.</param>
     public static implicit operator BasicMessageArgument(SignatureString arg)
-    {
-        return new SignatureMessageArgument(arg);
-    }
+        => FromSignatureString(arg);
+
+    /// <summary>
+    ///   Converts a <see cref="SignatureString" /> to a <see cref="BasicMessageArgument" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="arg">The <see cref="SignatureString" /> to be converted.</param>
+    public static BasicMessageArgument FromSignatureString(SignatureString arg)
+        => new SignatureMessageArgument(arg);
 
     /// <summary>
     /// Conversion operator of BasicMessageArgument from object path.
@@ -673,9 +883,15 @@ public abstract class BasicMessageArgument
     /// </summary>
     /// <param name="arg">The object path to be converted.</param>
     public static implicit operator BasicMessageArgument(ObjectPath arg)
-    {
-        return new ObjectPathMessageArgument(arg);
-    }
+        => FromObjectPath(arg);
+
+    /// <summary>
+    ///   Converts a <see cref="ObjectPath" /> to a <see cref="BasicMessageArgument" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="arg">The <see cref="ObjectPath" /> to be converted.</param>
+    public static BasicMessageArgument FromObjectPath(ObjectPath arg)
+        => new ObjectPathMessageArgument(arg);
 
     /// <summary>
     /// Conversion operator of BasicMessageArgument from unix fd.
@@ -683,9 +899,15 @@ public abstract class BasicMessageArgument
     /// </summary>
     /// <param name="arg">The unix fd to be converted.</param>
     public static implicit operator BasicMessageArgument(UnixFd arg)
-    {
-        return new UnixFdMessageArgument(arg);
-    }
+        => FromUnixFd(arg);
+
+    /// <summary>
+    ///   Converts a <see cref="UnixFd" /> to a <see cref="BasicMessageArgument" />.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="arg">The <see cref="UnixFd" /> to be converted.</param>
+    public static BasicMessageArgument FromUnixFd(UnixFd arg)
+        => new UnixFdMessageArgument(arg);
 }
 
 /// <summary>
@@ -727,12 +949,14 @@ public class ByteMessageArgument : BasicMessageArgument
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.Message msg)
     {
+        Contract.Requires(msg != null, nameof(msg));
         return eldbus_message_arguments_append(msg.Handle, Signature, value);
     }
 
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.MessageIterator iter)
     {
+        Contract.Requires(iter != null, nameof(iter));
         return eldbus_message_iter_basic_append(iter.Handle, TypeCode, value);
     }
 }
@@ -776,12 +1000,14 @@ public class BoolMessageArgument : BasicMessageArgument
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.Message msg)
     {
+        Contract.Requires(msg != null, nameof(msg));
         return eldbus_message_arguments_append(msg.Handle, Signature, value);
     }
 
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.MessageIterator iter)
     {
+        Contract.Requires(iter != null, nameof(iter));
         return eldbus_message_iter_basic_append(iter.Handle, TypeCode, value);
     }
 }
@@ -825,12 +1051,14 @@ public class Int16MessageArgument : BasicMessageArgument
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.Message msg)
     {
+        Contract.Requires(msg != null, nameof(msg));
         return eldbus_message_arguments_append(msg.Handle, Signature, value);
     }
 
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.MessageIterator iter)
     {
+        Contract.Requires(iter != null, nameof(iter));
         return eldbus_message_iter_basic_append(iter.Handle, TypeCode, value);
     }
 }
@@ -874,12 +1102,14 @@ public class UInt16MessageArgument : BasicMessageArgument
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.Message msg)
     {
+        Contract.Requires(msg != null, nameof(msg));
         return eldbus_message_arguments_append(msg.Handle, Signature, value);
     }
 
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.MessageIterator iter)
     {
+        Contract.Requires(iter != null, nameof(iter));
         return eldbus_message_iter_basic_append(iter.Handle, TypeCode, value);
     }
 }
@@ -923,12 +1153,14 @@ public class Int32MessageArgument : BasicMessageArgument
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.Message msg)
     {
+        Contract.Requires(msg != null, nameof(msg));
         return eldbus_message_arguments_append(msg.Handle, Signature, value);
     }
 
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.MessageIterator iter)
     {
+        Contract.Requires(iter != null, nameof(iter));
         return eldbus_message_iter_basic_append(iter.Handle, TypeCode, value);
     }
 }
@@ -972,12 +1204,14 @@ public class UInt32MessageArgument : BasicMessageArgument
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.Message msg)
     {
+        Contract.Requires(msg != null, nameof(msg));
         return eldbus_message_arguments_append(msg.Handle, Signature, value);
     }
 
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.MessageIterator iter)
     {
+        Contract.Requires(iter != null, nameof(iter));
         return eldbus_message_iter_basic_append(iter.Handle, TypeCode, value);
     }
 }
@@ -1021,12 +1255,14 @@ public class Int64MessageArgument : BasicMessageArgument
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.Message msg)
     {
+        Contract.Requires(msg != null, nameof(msg));
         return eldbus_message_arguments_append(msg.Handle, Signature, value);
     }
 
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.MessageIterator iter)
     {
+        Contract.Requires(iter != null, nameof(iter));
         return eldbus_message_iter_basic_append(iter.Handle, TypeCode, value);
     }
 }
@@ -1070,12 +1306,14 @@ public class UInt64MessageArgument : BasicMessageArgument
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.Message msg)
     {
+        Contract.Requires(msg != null, nameof(msg));
         return eldbus_message_arguments_append(msg.Handle, Signature, value);
     }
 
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.MessageIterator iter)
     {
+        Contract.Requires(iter != null, nameof(iter));
         return eldbus_message_iter_basic_append(iter.Handle, TypeCode, value);
     }
 }
@@ -1119,12 +1357,14 @@ public class DoubleMessageArgument : BasicMessageArgument
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.Message msg)
     {
+        Contract.Requires(msg != null, nameof(msg));
         return eldbus_message_arguments_append(msg.Handle, Signature, value);
     }
 
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.MessageIterator iter)
     {
+        Contract.Requires(iter != null, nameof(iter));
         return eldbus_message_iter_basic_append(iter.Handle, TypeCode, value);
     }
 }
@@ -1150,12 +1390,14 @@ public abstract class StringLikeMessageArgument : BasicMessageArgument
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.Message msg)
     {
+        Contract.Requires(msg != null, nameof(msg));
         return eldbus_message_arguments_append(msg.Handle, Signature, value);
     }
 
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.MessageIterator iter)
     {
+        Contract.Requires(iter != null, nameof(iter));
         return eldbus_message_iter_basic_append(iter.Handle, TypeCode, value);
     }
 }
@@ -1301,12 +1543,14 @@ public class UnixFdMessageArgument : BasicMessageArgument
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.Message msg)
     {
+        Contract.Requires(msg != null, nameof(msg));
         return eldbus_message_arguments_append(msg.Handle, Signature, value);
     }
 
     [EditorBrowsable(EditorBrowsableState.Never)]
     protected override bool InternalAppendTo(eldbus.MessageIterator iter)
     {
+        Contract.Requires(iter != null, nameof(iter));
         return eldbus_message_iter_basic_append(iter.Handle, TypeCode, value);
     }
 }
@@ -1323,12 +1567,15 @@ public delegate void MessageDelegate(eldbus.Message msg, eldbus.Pending pending)
 /// Commons for eldbus.
 /// <para>Since EFL 1.23.</para>
 /// </summary>
+[SuppressMessage("Microsoft.Naming", "CA1724:TypeNamesShouldNotMatchNamespaces")]
 public static class Common
 {
     /// <summary>
     /// Register the NullError.
     /// <para>Since EFL 1.23.</para>
     /// </summary>
+    [SuppressMessage("Microsoft.Design", "CA1030:UseEventsWhereAppropriate",
+                     Justification = "It's not an event.")]
     public static void RaiseNullHandle()
     {
         if (NullHandleError == 0)
@@ -1387,8 +1634,8 @@ public static class Common
             return;
         }
 
-        eldbus.Message msg;
-        eldbus.Pending pending;
+        eldbus.Message msg = null;
+        eldbus.Pending pending = null;
 
         try
         {
@@ -1398,6 +1645,11 @@ public static class Common
         catch (Exception e)
         {
             Eina.Log.Error("Eldbus: could not convert Eldbus_Message_Cb parameters. Exception: " + e.ToString());
+
+            if (msg != null)
+            {
+                msg.Dispose(); // CA2000
+            }
             return;
         }
 
@@ -1409,6 +1661,10 @@ public static class Common
         {
             Eina.Log.Error("Eldbus: Eldbus_Message_Cb delegate error. Exception: " + e.ToString());
         }
+        finally
+        {
+            msg.Dispose(); // CA2000
+        }
     }
 
     private static Eldbus_Message_Cb message_cb_wrapper = null;
