@@ -18,17 +18,6 @@
 #define MY_CLASS ECORE_AUDIO_CLASS
 #define MY_CLASS_NAME "Ecore_Audio"
 
-EOLIAN static void
-_ecore_audio_name_set(Eo *eo_obj EINA_UNUSED, Ecore_Audio_Object *obj, const char *name)
-{
-  eina_stringshare_replace(&obj->name, name);
-}
-
-EOLIAN static const char*
-_ecore_audio_name_get(Eo *eo_obj EINA_UNUSED, Ecore_Audio_Object *obj)
-{
-  return obj->name;
-}
 
 EOLIAN static void
 _ecore_audio_paused_set(Eo *eo_obj EINA_UNUSED, Ecore_Audio_Object *obj, Eina_Bool paused)
@@ -37,7 +26,7 @@ _ecore_audio_paused_set(Eo *eo_obj EINA_UNUSED, Ecore_Audio_Object *obj, Eina_Bo
 }
 
 EOLIAN static Eina_Bool
-_ecore_audio_paused_get(Eo *eo_obj EINA_UNUSED, Ecore_Audio_Object *obj)
+_ecore_audio_paused_get(const Eo *eo_obj EINA_UNUSED, Ecore_Audio_Object *obj)
 {
   return obj->paused;
 }
@@ -49,7 +38,7 @@ _ecore_audio_volume_set(Eo *eo_obj EINA_UNUSED, Ecore_Audio_Object *obj, double
 }
 
 EOLIAN static double
-_ecore_audio_volume_get(Eo *eo_obj EINA_UNUSED, Ecore_Audio_Object *obj)
+_ecore_audio_volume_get(const Eo *eo_obj EINA_UNUSED, Ecore_Audio_Object *obj)
 {
   return obj->volume;
 }
