@@ -32,7 +32,7 @@
  * counter, use eina_counter_new(). To free it, use
  * eina_counter_free().
  *
- * To time a part of a code, call eina_counter_start() just before it,
+ * To time a code sequence, call eina_counter_start() just before it,
  * and eina_counter_stop() just after it. Each time you start timing
  * a code, a clock is added to a list. You can give the number of that
  * clock with the second argument of eina_counter_stop(). To send all
@@ -124,7 +124,7 @@ typedef struct _Eina_Counter Eina_Counter;
  * @note When the new counter is not needed anymore, use eina_counter_free() to
  *       free the allocated memory.
  */
-EAPI Eina_Counter *eina_counter_new(const char *name) EINA_WARN_UNUSED_RESULT EINA_ARG_NONNULL(1);
+EINA_API Eina_Counter *eina_counter_new(const char *name) EINA_WARN_UNUSED_RESULT EINA_ARG_NONNULL(1);
 
 /**
  * @brief Deletes a counter.
@@ -135,7 +135,7 @@ EAPI Eina_Counter *eina_counter_new(const char *name) EINA_WARN_UNUSED_RESULT EI
  * @param[in] counter The counter to delete
  *
  */
-EAPI void          eina_counter_free(Eina_Counter *counter) EINA_ARG_NONNULL(1);
+EINA_API void          eina_counter_free(Eina_Counter *counter) EINA_ARG_NONNULL(1);
 
 /**
  * @brief Starts the time count.
@@ -152,7 +152,7 @@ EAPI void          eina_counter_free(Eina_Counter *counter) EINA_ARG_NONNULL(1);
  * @note To stop the timing, eina_counter_stop() must be called with the
  *       same counter.
  */
-EAPI void          eina_counter_start(Eina_Counter *counter) EINA_ARG_NONNULL(1);
+EINA_API void          eina_counter_start(Eina_Counter *counter) EINA_ARG_NONNULL(1);
 
 /**
  * @brief Stops the time count.
@@ -165,7 +165,7 @@ EAPI void          eina_counter_start(Eina_Counter *counter) EINA_ARG_NONNULL(1)
  * @param[in] specimen The number of the test
  *
  */
-EAPI void          eina_counter_stop(Eina_Counter *counter,
+EINA_API void          eina_counter_stop(Eina_Counter *counter,
                                      int           specimen) EINA_ARG_NONNULL(1);
 
 /**
@@ -185,7 +185,7 @@ EAPI void          eina_counter_stop(Eina_Counter *counter,
  *
  * @note The unit of time is nanoseconds.
  */
-EAPI char         *eina_counter_dump(Eina_Counter *counter) EINA_ARG_NONNULL(1);
+EINA_API char         *eina_counter_dump(Eina_Counter *counter) EINA_ARG_NONNULL(1);
 
 /**
  * @}
