@@ -66,7 +66,7 @@
 /*============================================================================*
  *                                   API                                      *
  *============================================================================*/
-EAPI Eina_Matrix_Type
+EINA_API Eina_Matrix_Type
 eina_matrix3_type_get(const Eina_Matrix3 *m)
 {
    if (!EINA_DBL_EQ(MATRIX_ZX(m), 0.0) ||
@@ -87,7 +87,7 @@ eina_matrix3_type_get(const Eina_Matrix3 *m)
      }
 }
 
-EAPI Eina_Matrix_Type
+EINA_API Eina_Matrix_Type
 eina_matrix4_type_get(const Eina_Matrix4 *m)
 {
    if (EINA_DBL_EQ(MATRIX_XX(m), 1.0) &&
@@ -110,7 +110,7 @@ eina_matrix4_type_get(const Eina_Matrix4 *m)
    return EINA_MATRIX_TYPE_AFFINE;
 }
 
-EAPI Eina_Matrix_Type
+EINA_API Eina_Matrix_Type
 eina_matrix3_f16p16_type_get(const Eina_Matrix3_F16p16 *m)
 {
    if ((MATRIX_ZX(m) != 0) || (MATRIX_ZY(m) != 0) || (MATRIX_ZZ(m) != 65536))
@@ -125,7 +125,7 @@ eina_matrix3_f16p16_type_get(const Eina_Matrix3_F16p16 *m)
      }
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_values_set(Eina_Matrix3 *m,
                         double xx, double xy, double xz,
                         double yx, double yy, double yz,
@@ -142,7 +142,7 @@ eina_matrix3_values_set(Eina_Matrix3 *m,
    MATRIX_ZZ(m) = zz;
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_values_get(const Eina_Matrix3 *m,
                         double *xx, double *xy, double *xz,
                         double *yx, double *yy, double *yz,
@@ -159,7 +159,7 @@ eina_matrix3_values_get(const Eina_Matrix3 *m,
    if (zz) *zz = MATRIX_ZZ(m);
 }
 
-EAPI void
+EINA_API void
 eina_matrix4_values_set(Eina_Matrix4 *m,
                         double xx, double xy, double xz, double xw,
                         double yx, double yy, double yz, double yw,
@@ -184,7 +184,7 @@ eina_matrix4_values_set(Eina_Matrix4 *m,
    MATRIX_WW(m) = ww;
 }
 
-EAPI void
+EINA_API void
 eina_matrix4_values_get(const Eina_Matrix4 *m,
                         double *xx, double *xy, double *xz, double *xw,
                         double *yx, double *yy, double *yz, double *yw,
@@ -209,7 +209,7 @@ eina_matrix4_values_get(const Eina_Matrix4 *m,
    if (ww) *ww = MATRIX_WW(m);
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_fixed_values_get(const Eina_Matrix3 *m,
                               Eina_F16p16 *xx, Eina_F16p16 *xy, Eina_F16p16 *xz,
                               Eina_F16p16 *yx, Eina_F16p16 *yy, Eina_F16p16 *yz,
@@ -226,7 +226,7 @@ eina_matrix3_fixed_values_get(const Eina_Matrix3 *m,
    if (zz) *zz = eina_f16p16_double_from(MATRIX_ZZ(m));
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_matrix3_f16p16_to(const Eina_Matrix3 *m,
                                Eina_Matrix3_F16p16 *fm)
 {
@@ -236,7 +236,7 @@ eina_matrix3_matrix3_f16p16_to(const Eina_Matrix3 *m,
                                  &fm->zx, &fm->zy, &fm->zz);
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_point_transform(const Eina_Matrix3 *m,
                              double x, double y,
                              double *xr, double *yr)
@@ -261,7 +261,7 @@ eina_matrix3_point_transform(const Eina_Matrix3 *m,
    if (yr) *yr = yrr;
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_rectangle_transform(const Eina_Matrix3 *m,
                                  const Eina_Rectangle *r,
                                  const Eina_Quad *q)
@@ -272,7 +272,7 @@ eina_matrix3_rectangle_transform(const Eina_Matrix3 *m,
    eina_matrix3_point_transform(m, r->x, r->y + r->h, &((Eina_Quad *)q)->x3, &((Eina_Quad *)q)->y3);
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_cofactor(const Eina_Matrix3 *m, Eina_Matrix3 *a)
 {
    double a11, a12, a13, a21, a22, a23, a31, a32, a33;
@@ -302,7 +302,7 @@ eina_matrix3_cofactor(const Eina_Matrix3 *m, Eina_Matrix3 *a)
    MATRIX_ZZ(a) = a33;
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_transpose(const Eina_Matrix3 *m, Eina_Matrix3 *a)
 {
    MATRIX_XX(a) = MATRIX_XX(m);
@@ -318,7 +318,7 @@ eina_matrix3_transpose(const Eina_Matrix3 *m, Eina_Matrix3 *a)
    MATRIX_ZZ(a) = MATRIX_ZZ(m);
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_adjoint(const Eina_Matrix3 *m, Eina_Matrix3 *a)
 {
    Eina_Matrix3 cofactor;
@@ -329,7 +329,7 @@ eina_matrix3_adjoint(const Eina_Matrix3 *m, Eina_Matrix3 *a)
    eina_matrix3_transpose(&cofactor, a);
 }
 
-EAPI double
+EINA_API double
 eina_matrix3_determinant(const Eina_Matrix3 *m)
 {
    double det;
@@ -341,7 +341,7 @@ eina_matrix3_determinant(const Eina_Matrix3 *m)
    return det;
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_divide(Eina_Matrix3 *m, double scalar)
 {
    MATRIX_XX(m) /= scalar;
@@ -357,7 +357,7 @@ eina_matrix3_divide(Eina_Matrix3 *m, double scalar)
    MATRIX_ZZ(m) /= scalar;
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_inverse(const Eina_Matrix3 *m, Eina_Matrix3 *m2)
 {
    double scalar;
@@ -375,7 +375,7 @@ eina_matrix3_inverse(const Eina_Matrix3 *m, Eina_Matrix3 *m2)
    eina_matrix3_divide(m2, scalar);
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_compose(const Eina_Matrix3 *m1,
                      const Eina_Matrix3 *m2,
                      Eina_Matrix3 *dst)
@@ -405,7 +405,7 @@ eina_matrix3_compose(const Eina_Matrix3 *m1,
    MATRIX_ZZ(dst) = a33;
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_matrix3_equal(const Eina_Matrix3 *m1, const Eina_Matrix3 *m2)
 {
    if (!EINA_DBL_EQ(m1->xx, m2->xx) ||
@@ -421,7 +421,7 @@ eina_matrix3_equal(const Eina_Matrix3 *m1, const Eina_Matrix3 *m2)
    return EINA_TRUE;
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_f16p16_compose(const Eina_Matrix3_F16p16 *m1,
                             const Eina_Matrix3_F16p16 *m2,
                             Eina_Matrix3_F16p16 *dst)
@@ -469,7 +469,7 @@ eina_matrix3_f16p16_compose(const Eina_Matrix3_F16p16 *m1,
    MATRIX_ZZ(dst) = a33;
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_translate(Eina_Matrix3 *m, double tx, double ty)
 {
    Eina_Matrix3 tmp;
@@ -485,7 +485,7 @@ eina_matrix3_translate(Eina_Matrix3 *m, double tx, double ty)
    eina_matrix3_compose(m, &tmp, m);
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_scale(Eina_Matrix3 *m, double sx, double sy)
 {
    Eina_Matrix3 tmp;
@@ -501,7 +501,7 @@ eina_matrix3_scale(Eina_Matrix3 *m, double sx, double sy)
    eina_matrix3_compose(m, &tmp, m);
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_rotate(Eina_Matrix3 *m, double rad)
 {
    double c, s;
@@ -536,7 +536,7 @@ eina_matrix3_rotate(Eina_Matrix3 *m, double rad)
    eina_matrix3_compose(m, &tmp, m);
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_identity(Eina_Matrix3 *m)
 {
    MATRIX_XX(m) = 1;
@@ -550,7 +550,7 @@ eina_matrix3_identity(Eina_Matrix3 *m)
    MATRIX_ZZ(m) = 1;
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_f16p16_identity(Eina_Matrix3_F16p16 *m)
 {
    MATRIX_XX(m) = 65536;
@@ -564,7 +564,7 @@ eina_matrix3_f16p16_identity(Eina_Matrix3_F16p16 *m)
    MATRIX_ZZ(m) = 65536;
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_matrix3_square_quad_map(Eina_Matrix3 *m, const Eina_Quad *q)
 {
    // x0 - x1 + x2 - x3
@@ -615,7 +615,7 @@ eina_matrix3_square_quad_map(Eina_Matrix3 *m, const Eina_Quad *q)
      }
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_matrix3_quad_square_map(Eina_Matrix3 *m,
                              const Eina_Quad *q)
 {
@@ -635,7 +635,7 @@ eina_matrix3_quad_square_map(Eina_Matrix3 *m,
    return EINA_TRUE;
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_matrix3_quad_quad_map(Eina_Matrix3 *m,
                            const Eina_Quad *src,
                            const Eina_Quad *dst)
@@ -652,7 +652,7 @@ eina_matrix3_quad_quad_map(Eina_Matrix3 *m,
    return EINA_TRUE;
 }
 
-EAPI void
+EINA_API void
 eina_matrix4_matrix3_to(Eina_Matrix3 *m3, const Eina_Matrix4 *m4)
 {
    MATRIX_XX(m3) = MATRIX_XX(m4);
@@ -666,7 +666,7 @@ eina_matrix4_matrix3_to(Eina_Matrix3 *m3, const Eina_Matrix4 *m4)
    MATRIX_ZZ(m3) = MATRIX_WW(m4);
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_matrix4_to(Eina_Matrix4 *m4, const Eina_Matrix3 *m3)
 {
    MATRIX_XX(m4) = MATRIX_XX(m3);
@@ -687,7 +687,7 @@ eina_matrix3_matrix4_to(Eina_Matrix4 *m4, const Eina_Matrix3 *m3)
    MATRIX_WW(m4) = MATRIX_ZZ(m3);
 }
 
-EAPI double
+EINA_API double
 eina_matrix4_determinant(const Eina_Matrix4 *m)
 {
    return
@@ -717,7 +717,7 @@ eina_matrix4_determinant(const Eina_Matrix4 *m)
      + MATRIX_XX(m) * MATRIX_YY(m) * MATRIX_ZZ(m) * MATRIX_WW(m);
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_matrix4_normalized(Eina_Matrix4 *out, const Eina_Matrix4 *in)
 {
    double det;
@@ -745,7 +745,7 @@ eina_matrix4_normalized(Eina_Matrix4 *out, const Eina_Matrix4 *in)
    return EINA_TRUE;
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_matrix4_inverse(Eina_Matrix4 *out, const Eina_Matrix4 *in)
 {
    double det;
@@ -908,7 +908,7 @@ eina_matrix4_inverse(Eina_Matrix4 *out, const Eina_Matrix4 *in)
    return EINA_TRUE;
 }
 
-EAPI void
+EINA_API void
 eina_matrix4_transpose(Eina_Matrix4 *out, const Eina_Matrix4 *in)
 {
    MATRIX_XX(out) = MATRIX_XX(in);
@@ -929,7 +929,7 @@ eina_matrix4_transpose(Eina_Matrix4 *out, const Eina_Matrix4 *in)
    MATRIX_WW(out) = MATRIX_WW(in);
 }
 
-EAPI void
+EINA_API void
 eina_matrix4_multiply_copy(Eina_Matrix4 *out,
                       const Eina_Matrix4 *mat_a, const Eina_Matrix4 *mat_b)
 {
@@ -946,7 +946,7 @@ eina_matrix4_multiply_copy(Eina_Matrix4 *out,
      }
 }
 
-EAPI void
+EINA_API void
 eina_matrix4_identity(Eina_Matrix4 *out)
 {
    memset(out, 0, sizeof (Eina_Matrix4));
@@ -957,7 +957,7 @@ eina_matrix4_identity(Eina_Matrix4 *out)
    MATRIX_WW(out) = 1.0;
 }
 
-EAPI Eina_Matrix_Type
+EINA_API Eina_Matrix_Type
 eina_matrix2_type_get(const Eina_Matrix2 *m)
 {
    if (EINA_DBL_EQ(MATRIX_XX(m), 1.0) &&
@@ -968,19 +968,19 @@ eina_matrix2_type_get(const Eina_Matrix2 *m)
    return EINA_MATRIX_TYPE_AFFINE;
 }
 
-EAPI void
+EINA_API void
 eina_matrix4_array_set(Eina_Matrix4 *m, const double *v)
 {
    memcpy(&MATRIX_XX(m), v, sizeof(double) * 16);
 }
 
-EAPI void
+EINA_API void
 eina_matrix4_copy(Eina_Matrix4 *dst, const Eina_Matrix4 *src)
 {
    memcpy(dst, src, sizeof(Eina_Matrix4));
 }
 
-EAPI void
+EINA_API void
 eina_matrix4_multiply(Eina_Matrix4 *out, const Eina_Matrix4 *mat_a,
                            const Eina_Matrix4 *mat_b)
 {
@@ -999,7 +999,7 @@ eina_matrix4_multiply(Eina_Matrix4 *out, const Eina_Matrix4 *mat_a,
    eina_matrix4_compose(mat_a, mat_b, out);
 }
 
-EAPI void
+EINA_API void
 eina_matrix4_ortho_set(Eina_Matrix4 *m,
                     double left, double right, double bottom, double top,
                     double dnear, double dfar)
@@ -1029,7 +1029,7 @@ eina_matrix4_ortho_set(Eina_Matrix4 *m,
    MATRIX_WW(m) = 1.0f;
 }
 
-EAPI void
+EINA_API void
 eina_matrix4_compose(const Eina_Matrix4 *mat_a,
                      const Eina_Matrix4 *mat_b,
                      Eina_Matrix4 *out)
@@ -1096,7 +1096,7 @@ eina_matrix4_compose(const Eina_Matrix4 *mat_a,
    MATRIX_WW(out) = ww;
 }
 
-EAPI void
+EINA_API void
 eina_matrix4_translate(Eina_Matrix4 *t, double tx, double ty, double tz)
 {
    Eina_Matrix4 tmp;
@@ -1123,7 +1123,7 @@ eina_matrix4_translate(Eina_Matrix4 *t, double tx, double ty, double tz)
    eina_matrix4_compose(&tmp, t, t);
 }
 
-EAPI void
+EINA_API void
 eina_matrix4_scale(Eina_Matrix4 *t, double sx, double sy, double sz)
 {
    Eina_Matrix4 tmp;
@@ -1150,7 +1150,7 @@ eina_matrix4_scale(Eina_Matrix4 *t, double sx, double sy, double sz)
    eina_matrix4_compose(&tmp, t, t);
 }
 
-EAPI void
+EINA_API void
 eina_matrix4_rotate(Eina_Matrix4 *t, double rad, Eina_Matrix_Axis axis)
 {
    double c, s;
@@ -1199,19 +1199,19 @@ eina_matrix4_rotate(Eina_Matrix4 *t, double rad, Eina_Matrix_Axis axis)
    eina_matrix4_compose(&tmp, t, t);
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_array_set(Eina_Matrix3 *m, const double *v)
 {
    memcpy(&MATRIX_XX(m), v, sizeof(double) * 9);
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_copy(Eina_Matrix3 *dst, const Eina_Matrix3 *src)
 {
    memcpy(dst, src, sizeof(Eina_Matrix3));
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_multiply(Eina_Matrix3 *out, const Eina_Matrix3 *mat_a, const Eina_Matrix3 *mat_b)
 {
    if (eina_matrix3_type_get(mat_a) == EINA_MATRIX_TYPE_IDENTITY)
@@ -1229,7 +1229,7 @@ eina_matrix3_multiply(Eina_Matrix3 *out, const Eina_Matrix3 *mat_a, const Eina_M
    eina_matrix3_compose(mat_a, mat_b, out);
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_multiply_copy(Eina_Matrix3 *out, const Eina_Matrix3 *mat_a, const Eina_Matrix3 *mat_b)
 {
    if (out != mat_a && out != mat_b)
@@ -1245,7 +1245,7 @@ eina_matrix3_multiply_copy(Eina_Matrix3 *out, const Eina_Matrix3 *mat_a, const E
      }
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_position_transform_set(Eina_Matrix3 *out, const double p_x,
 								 const double p_y)
 {
@@ -1254,7 +1254,7 @@ eina_matrix3_position_transform_set(Eina_Matrix3 *out, const double p_x,
    MATRIX_YZ(out) = p_y;
 }
 
-EAPI void
+EINA_API void
 eina_matrix3_scale_transform_set(Eina_Matrix3 *out, double s_x, double s_y)
 {
    eina_matrix3_identity(out);
@@ -1262,7 +1262,7 @@ eina_matrix3_scale_transform_set(Eina_Matrix3 *out, double s_x, double s_y)
    MATRIX_YY(out) = s_y;
 }
 
-EAPI void
+EINA_API void
 eina_normal3_matrix_get(Eina_Matrix3 *out, const Eina_Matrix4 *m)
 {
    /* Normal matrix is a transposed matrix of inversed modelview.
@@ -1300,7 +1300,7 @@ eina_normal3_matrix_get(Eina_Matrix3 *out, const Eina_Matrix4 *m)
    MATRIX_ZZ(out) = (a * e - d * b) * det;
 }
 
-EAPI void
+EINA_API void
 eina_matrix2_values_set(Eina_Matrix2 *m,
                         double xx, double xy,
                         double yx, double yy)
@@ -1311,7 +1311,7 @@ eina_matrix2_values_set(Eina_Matrix2 *m,
    MATRIX_YY(m) = yy;
 }
 
-EAPI void
+EINA_API void
 eina_matrix2_values_get(const Eina_Matrix2 *m,
                         double *xx, double *xy,
                         double *yx, double *yy)
@@ -1322,7 +1322,7 @@ eina_matrix2_values_get(const Eina_Matrix2 *m,
    if (yy) *yy = MATRIX_YY(m);
 }
 
-EAPI void
+EINA_API void
 eina_matrix2_inverse(Eina_Matrix2 *out, const Eina_Matrix2 *mat)
 {
    double         det;
@@ -1346,7 +1346,7 @@ eina_matrix2_inverse(Eina_Matrix2 *out, const Eina_Matrix2 *mat)
    MATRIX_YY(out) =  MATRIX_XX(mat) * det;
 }
 
-EAPI void
+EINA_API void
 eina_matrix2_identity(Eina_Matrix2 *m)
 {
    MATRIX_XX(m) = 1.0;
@@ -1356,19 +1356,19 @@ eina_matrix2_identity(Eina_Matrix2 *m)
    MATRIX_YY(m) = 1.0;
 }
 
-EAPI void
+EINA_API void
 eina_matrix2_array_set(Eina_Matrix2 *m, const double *v)
 {
    memcpy(&MATRIX_XX(m), v, sizeof(double) * 4);
 }
 
-EAPI void
+EINA_API void
 eina_matrix2_copy(Eina_Matrix2 *dst, const Eina_Matrix2 *src)
 {
    memcpy(dst, src, sizeof(Eina_Matrix2));
 }
 
-EAPI void
+EINA_API void
 eina_matrix2_multiply(Eina_Matrix2 *out, const Eina_Matrix2 *mat_a, const Eina_Matrix2 *mat_b)
 {
    if (eina_matrix2_type_get(mat_a) == EINA_MATRIX_TYPE_IDENTITY)
@@ -1390,7 +1390,7 @@ eina_matrix2_multiply(Eina_Matrix2 *out, const Eina_Matrix2 *mat_a, const Eina_M
    MATRIX_YY(out) = MATRIX_XY(mat_a) * MATRIX_YX(mat_b) + MATRIX_YY(mat_a) * MATRIX_YY(mat_b);
 }
 
-EAPI void
+EINA_API void
 eina_matrix2_multiply_copy(Eina_Matrix2 *out, const Eina_Matrix2 *mat_a, const Eina_Matrix2 *mat_b)
 {
    if (out != mat_a && out != mat_b)
