@@ -140,7 +140,7 @@ static const Eina_Value_Struct_Desc RACE_STRUCT_DESC = {
 };
 
 /** @cond local */
-EAPI const Eina_Value_Struct_Desc *EINA_PROMISE_RACE_STRUCT_DESC = &RACE_STRUCT_DESC;
+EINA_API const Eina_Value_Struct_Desc *EINA_PROMISE_RACE_STRUCT_DESC = &RACE_STRUCT_DESC;
 /** @endcond */
 
 static inline void
@@ -574,7 +574,7 @@ eina_promise_init(void)
    return EINA_FALSE;
 }
 
-EAPI void
+EINA_API void
 __eina_promise_cancel_all(void)
 {
    eina_lock_take(&_pending_futures_lock);
@@ -583,7 +583,7 @@ __eina_promise_cancel_all(void)
    eina_lock_release(&_pending_futures_lock);
 }
 
-EAPI void
+EINA_API void
 __eina_promise_cancel_data(void *data)
 {
    Eina_List *del = NULL, *l;
@@ -618,7 +618,7 @@ eina_promise_shutdown(void)
    return EINA_TRUE;
 }
 
-EAPI Eina_Value
+EINA_API Eina_Value
 eina_promise_as_value(Eina_Promise *p)
 {
    Eina_Value v = EINA_VALUE_EMPTY;
@@ -698,7 +698,7 @@ _scheduler_get(Eina_Future *f)
    return NULL;
 }
 
-EAPI Eina_Value
+EINA_API Eina_Value
 eina_future_as_value(Eina_Future *f)
 {
    Eina_Value v = EINA_VALUE_EMPTY;
@@ -739,7 +739,7 @@ eina_future_as_value(Eina_Future *f)
    return v;
 }
 
-EAPI Eina_Promise *
+EINA_API Eina_Promise *
 eina_promise_new(Eina_Future_Scheduler *scheduler,
                  Eina_Promise_Cancel_Cb cancel_cb, const void *data)
 {
@@ -758,7 +758,7 @@ eina_promise_new(Eina_Future_Scheduler *scheduler,
    return p;
 }
 
-EAPI Eina_Promise *
+EINA_API Eina_Promise *
 eina_promise_continue_new(const Eina_Future *dead_future,
                           Eina_Promise_Cancel_Cb cancel_cb, const void *data)
 {
@@ -777,14 +777,14 @@ eina_promise_continue_new(const Eina_Future *dead_future,
    return p;
 }
 
-EAPI void
+EINA_API void
 eina_future_cancel(Eina_Future *f)
 {
    EINA_FUTURE_CHECK_RETURN(f);
    _eina_future_cancel(f, ECANCELED);
 }
 
-EAPI void
+EINA_API void
 eina_promise_resolve(Eina_Promise *p, Eina_Value value)
 {
    EINA_PROMISE_CHECK_GOTO(p, err);
@@ -795,7 +795,7 @@ eina_promise_resolve(Eina_Promise *p, Eina_Value value)
    eina_value_flush(&value);
 }
 
-EAPI void
+EINA_API void
 eina_promise_reject(Eina_Promise *p, Eina_Error err)
 {
    Eina_Value value;
@@ -863,7 +863,7 @@ _eina_future_new(Eina_Promise *p, const Eina_Future_Desc desc)
    return NULL;
 }
 
-EAPI Eina_Future *
+EINA_API Eina_Future *
 eina_future_new(Eina_Promise *p)
 {
    static const Eina_Future_Desc desc = {
@@ -898,7 +898,7 @@ _eina_future_then(Eina_Future *prev, const Eina_Future_Desc desc)
    return NULL;
 }
 
-EAPI Eina_Future *
+EINA_API Eina_Future *
 eina_future_resolved(Eina_Future_Scheduler *scheduler, Eina_Value value)
 {
    Eina_Promise *p;
@@ -920,7 +920,7 @@ eina_future_resolved(Eina_Future_Scheduler *scheduler, Eina_Value value)
    return NULL;
 }
 
-EAPI Eina_Future *
+EINA_API Eina_Future *
 eina_future_rejected(Eina_Future_Scheduler *scheduler, Eina_Error err)
 {
    Eina_Promise *p;
@@ -941,7 +941,7 @@ eina_future_rejected(Eina_Future_Scheduler *scheduler, Eina_Error err)
    return NULL;
 }
 
-EAPI Eina_Future *
+EINA_API Eina_Future *
 eina_future_then_from_desc(Eina_Future *prev, const Eina_Future_Desc desc)
 {
    EINA_FUTURE_CHECK_GOTO(prev, err_future);
@@ -955,7 +955,7 @@ eina_future_then_from_desc(Eina_Future *prev, const Eina_Future_Desc desc)
    return NULL;
 }
 
-EAPI Eina_Future *
+EINA_API Eina_Future *
 eina_future_chain_array(Eina_Future *prev, const Eina_Future_Desc descs[])
 {
    Eina_Future *f = prev;
@@ -991,7 +991,7 @@ eina_future_chain_array(Eina_Future *prev, const Eina_Future_Desc descs[])
    return NULL;
 }
 
-EAPI Eina_Future *
+EINA_API Eina_Future *
 eina_future_chain_easy_array(Eina_Future *prev, const Eina_Future_Cb_Easy_Desc descs[])
 {
    size_t i = -1;
@@ -1060,7 +1060,7 @@ _eina_future_cb_console(void *data,
    return value;
 }
 
-EAPI Eina_Future_Desc
+EINA_API Eina_Future_Desc
 eina_future_cb_console_from_desc(const Eina_Future_Cb_Console_Desc desc)
 {
    Eina_Future_Cb_Console_Desc *c;
@@ -1112,7 +1112,7 @@ _eina_future_cb_convert_to(void *data, const Eina_Value src,
     return dst;
 }
 
-EAPI Eina_Future_Desc
+EINA_API Eina_Future_Desc
 eina_future_cb_convert_to(const Eina_Value_Type *type)
 {
    return (Eina_Future_Desc){.cb = _eina_future_cb_convert_to, .data = type};
@@ -1134,7 +1134,7 @@ _eina_future_cb_easy(void *data, const Eina_Value value,
     return ret;
 }
 
-EAPI Eina_Future_Desc
+EINA_API Eina_Future_Desc
 eina_future_cb_easy_from_desc(const Eina_Future_Cb_Easy_Desc desc)
 {
    Eina_Future_Cb_Easy_Desc *d = calloc(1, sizeof(Eina_Future_Cb_Easy_Desc));
@@ -1148,6 +1148,7 @@ typedef struct _Base_Ctx {
    Eina_Promise *promise;
    Eina_Future **futures;
    unsigned int futures_len;
+   Eina_Bool cancelled : 1;
 } Base_Ctx;
 
 typedef struct _All_Promise_Ctx {
@@ -1173,6 +1174,7 @@ _base_ctx_clean(Base_Ctx *ctx)
 static void
 _all_promise_ctx_free(All_Promise_Ctx *ctx)
 {
+   DBG("Cleaning base_ctx for %p", ctx);
    _base_ctx_clean(&ctx->base);
    eina_value_flush(&ctx->values);
    free(ctx);
@@ -1181,12 +1183,16 @@ _all_promise_ctx_free(All_Promise_Ctx *ctx)
 static void
 _all_promise_cancel(void *data, const Eina_Promise *dead EINA_UNUSED)
 {
-   _all_promise_ctx_free(data);
+   All_Promise_Ctx *ctx = data;
+
+   ctx->base.cancelled = 1;
+   _all_promise_ctx_free(ctx);
 }
 
 static void
 _race_promise_ctx_free(Race_Promise_Ctx *ctx)
 {
+   DBG("Cleaning base_ctx for %p", ctx);
    _base_ctx_clean(&ctx->base);
    free(ctx);
 }
@@ -1194,6 +1200,9 @@ _race_promise_ctx_free(Race_Promise_Ctx *ctx)
 static void
 _race_promise_cancel(void *data, const Eina_Promise *dead EINA_UNUSED)
 {
+   Race_Promise_Ctx *ctx = data;
+
+   ctx->base.cancelled = 1;
    _race_promise_ctx_free(data);
 }
 
@@ -1233,7 +1242,8 @@ _race_then_cb(void *data, const Eina_Value v,
    ctx->dispatching = EINA_TRUE;
 
    //By freeing the race_ctx all the other futures will be cancelled.
-   _race_promise_ctx_free(ctx);
+   if (!ctx->base.cancelled)
+     _race_promise_ctx_free(ctx);
 
    r = eina_value_struct_setup(&result, &RACE_STRUCT_DESC);
    EINA_SAFETY_ON_FALSE_GOTO(r, err_setup);
@@ -1275,7 +1285,8 @@ _all_then_cb(void *data, const Eina_Value v,
         //We're in a safe context (from mainloop), so we can avoid scheduling a new dispatch
         _eina_promise_clean_dispatch(ctx->base.promise, ctx->values);
         ctx->values = EINA_VALUE_EMPTY; /* flushed in _eina_promise_clean_dispatch() */
-        _all_promise_ctx_free(ctx);
+        if (!ctx->base.cancelled)
+          _all_promise_ctx_free(ctx);
      }
    return v;
 }
@@ -1329,7 +1340,7 @@ promise_proxy_of_future_array_create(Eina_Future *array[],
    return EINA_FALSE;
 }
 
-EAPI Eina_Promise *
+EINA_API Eina_Promise *
 eina_promise_all_iterator(Eina_Iterator *it)
 {
    All_Promise_Ctx *ctx;
@@ -1393,7 +1404,7 @@ eina_promise_all_iterator(Eina_Iterator *it)
    return NULL;
 }
 
-EAPI Eina_Promise *
+EINA_API Eina_Promise *
 eina_promise_all_array(Eina_Future *array[])
 {
    All_Promise_Ctx *ctx;
@@ -1436,7 +1447,7 @@ eina_promise_all_array(Eina_Future *array[])
    return NULL;
 }
 
-EAPI Eina_Promise *
+EINA_API Eina_Promise *
 eina_promise_race_array(Eina_Future *array[])
 {
    Race_Promise_Ctx *ctx;
@@ -1468,7 +1479,9 @@ _eina_future_cb_ignore_error(void *data, const Eina_Value value,
    if (value.type == EINA_VALUE_TYPE_ERROR)
      {
         Eina_Error err;
-        eina_value_get(&value, &err);
+
+        if (!eina_value_get(&value, &err))
+          return EINA_VALUE_EMPTY;
         if ((!expected_err) || (expected_err == err))
           {
              DBG("ignored error %d (%s)", err, eina_error_msg_get(err));
@@ -1478,13 +1491,13 @@ _eina_future_cb_ignore_error(void *data, const Eina_Value value,
    return value;
 }
 
-EAPI Eina_Future_Desc
+EINA_API Eina_Future_Desc
 eina_future_cb_ignore_error(Eina_Error err)
 {
    return (Eina_Future_Desc){ _eina_future_cb_ignore_error, (void*)(uintptr_t)err, NULL };
 }
 
-EAPI void
+EINA_API void
 eina_future_desc_flush(Eina_Future_Desc *desc)
 {
    if (!desc) return;
@@ -1492,7 +1505,7 @@ eina_future_desc_flush(Eina_Future_Desc *desc)
    memset(desc, 0, sizeof(Eina_Future_Desc));
 }
 
-EAPI void
+EINA_API void
 eina_future_cb_easy_desc_flush(Eina_Future_Cb_Easy_Desc *desc)
 {
    if (!desc) return;
@@ -1541,7 +1554,7 @@ _future_cb_log(void *data, const Eina_Value value,
    return value;
 }
 
-EAPI Eina_Future_Desc
+EINA_API Eina_Future_Desc
 eina_future_cb_log_from_desc(const Eina_Future_Cb_Log_Desc desc)
 {
    Eina_Future_Cb_Log_Desc *ctx = calloc(1, sizeof(Eina_Future_Cb_Log_Desc));
