@@ -2164,25 +2164,6 @@ _icon_size_min_get(Evas_Object *image)
    return MAX(16, MIN(w, h));
 }
 
-/* FIXME: move this code to ecore */
-#ifdef _WIN32
-static Eina_Bool
-_path_is_absolute(const char *path)
-{
-   //TODO: Check if this works with all absolute paths in windows
-   return (isalpha(*path)) && (*(path + 1) == ':') &&
-           ((*(path + 2) == '\\') || (*(path + 2) == '/'));
-}
-
-#else
-static Eina_Bool
-_path_is_absolute(const char *path)
-{
-   return *path == '/';
-}
-
-#endif
-
 static Eina_Bool
 _internal_efl_ui_image_icon_set(Evas_Object *obj, const char *name, Eina_Bool *fdo)
 {
@@ -2217,7 +2198,7 @@ _internal_efl_ui_image_icon_set(Evas_Object *obj, const char *name, Eina_Bool *f
    else
      eina_stringshare_replace(&sd->stdicon, NULL);
 
-   if (_path_is_absolute(name))
+   if (!eina_file_path_relative(name))
      {
         if (fdo)
           *fdo = EINA_FALSE;
