@@ -13,30 +13,37 @@
   Efl_Ui_Position_Manager_Grid_Data *pd = efl_data_scope_get(obj, MY_CLASS);
 
 typedef struct {
-   unsigned int size;
-   unsigned int groups;
+   Api_Callbacks callbacks;
+
+   Eina_Inarray *group_cache;
+   int *size_cache;
+   Eo *last_group;
+   Eina_Future *rebuild_absolut_size;
+   Efl_Ui_Win *window;
+   Evas *canvas;
+
+   Vis_Segment prev_run;
+
    Eina_Rect viewport;
    Eina_Vector2 scroll_position;
-   Efl_Ui_Layout_Orientation dir;
-   Vis_Segment prev_run;
-   unsigned int prev_consumed_space;
    Eina_Size2D max_min_size;
    Eina_Size2D last_viewport_size;
    Eina_Size2D prev_min_size;
 
-   Eina_Inarray *group_cache;
+   Efl_Ui_Layout_Orientation dir;
+
+   unsigned int size;
+   unsigned int groups;
+   unsigned int prev_consumed_space;
+
    Eina_Bool group_cache_dirty;
-   int *size_cache;
    Eina_Bool size_cache_dirty;
-   Eo *last_group;
-   Eina_Future *rebuild_absolut_size;
-   Api_Callbacks callbacks;
 } Efl_Ui_Position_Manager_Grid_Data;
 
 typedef struct {
-   Eina_Bool real_group;
    Eina_Size2D group_header_size;
    int items;
+   Eina_Bool real_group;
 } Group_Cache_Line;
 
 static inline void
@@ -706,6 +713,7 @@ _efl_ui_position_manager_grid_efl_ui_position_manager_entity_position_single_ite
      EINA_SAFETY_ON_FALSE_RETURN_VAL(group_consumed_ids == 0, EINA_RECT(0, 0, 0, 0));
 
    int columns = pd->viewport.w/pd->max_min_size.w;
+   if (columns == 0) return EINA_RECT(0, 0, 0, 0);
    int sub_pos_id = idx - group_consumed_ids;
 
    if (pd->dir == EFL_UI_LAYOUT_ORIENTATION_VERTICAL)
@@ -730,35 +738,34 @@ _efl_ui_position_manager_grid_efl_ui_position_manager_entity_position_single_ite
    return geom;
 }
 
-EOLIAN static int
-_efl_ui_position_manager_grid_efl_ui_position_manager_entity_relative_item(Eo *obj EINA_UNUSED, Efl_Ui_Position_Manager_Grid_Data *pd, unsigned int current_id, Efl_Ui_Focus_Direction direction)
+EOLIAN static Eina_Bool
+_efl_ui_position_manager_grid_efl_ui_position_manager_entity_relative_item(Eo *obj EINA_UNUSED, Efl_Ui_Position_Manager_Grid_Data *pd, unsigned int current_id, Efl_Ui_Focus_Direction direction, unsigned int *index)
 {
-   int new_id = current_id;
    switch(direction)
      {
         case EFL_UI_FOCUS_DIRECTION_RIGHT:
         case EFL_UI_FOCUS_DIRECTION_NEXT:
-          new_id += 1;
-        break;
+           if (current_id + 1 >= pd->size) return EINA_FALSE;
+           current_id += 1;
+           break;
         case EFL_UI_FOCUS_DIRECTION_LEFT:
         case EFL_UI_FOCUS_DIRECTION_PREVIOUS:
-          new_id -= 1;
-        break;
+           if (current_id == 0) return EINA_FALSE;
+           current_id -= 1;
+           break;
         case EFL_UI_FOCUS_DIRECTION_UP:
-          //FIXME
-        break;
+           //FIXME
+           break;
         case EFL_UI_FOCUS_DIRECTION_DOWN:
-          //FIXME
-        break;
+           //FIXME
+           break;
         default:
-          new_id = -1;
-          ERR("Uncaught case!");
-        break;
+           ERR("Uncaught case!");
+           return EINA_FALSE;
      }
-   if (new_id < 0 || new_id > (int)pd->size)
-     return -1;
-   else
-     return new_id;
+
+   if (index) *index = current_id;
+   return EINA_TRUE;
 }
 
 EOLIAN static int
@@ -768,7 +775,7 @@ _efl_ui_position_manager_grid_efl_ui_position_manager_entity_version(Eo *obj EIN
 }
 
 EOLIAN static void
-_efl_ui_position_manager_grid_efl_ui_position_manager_data_access_v1_data_access_set(Eo *obj, Efl_Ui_Position_Manager_Grid_Data *pd, void *obj_access_data, Efl_Ui_Position_Manager_Object_Batch_Callback obj_access, Eina_Free_Cb obj_access_free_cb, void *size_access_data, Efl_Ui_Position_Manager_Size_Batch_Callback size_access, Eina_Free_Cb size_access_free_cb, int size)
+_efl_ui_position_manager_grid_efl_ui_position_manager_data_access_v1_data_access_set(Eo *obj, Efl_Ui_Position_Manager_Grid_Data *pd, Efl_Ui_Win *canvas, void *obj_access_data, Efl_Ui_Position_Manager_Object_Batch_Callback obj_access, Eina_Free_Cb obj_access_free_cb, void *size_access_data, Efl_Ui_Position_Manager_Size_Batch_Callback size_access, Eina_Free_Cb size_access_free_cb, int size)
 {
    // Cleanup cache first
    _group_cache_invalidate(obj, pd);
@@ -780,6 +787,9 @@ _efl_ui_position_manager_grid_efl_ui_position_manager_data_access_v1_data_access
      pd->callbacks.size.free_cb(pd->callbacks.size.data);
 
    // Set them
+   efl_replace(&pd->window, canvas);
+   efl_replace(&pd->canvas, canvas ? evas_object_evas_get(canvas) : NULL);
+
    pd->callbacks.object.data = obj_access_data;
    pd->callbacks.object.access = obj_access;
    pd->callbacks.object.free_cb = obj_access_free_cb;
@@ -796,7 +806,7 @@ EOLIAN static void
 _efl_ui_position_manager_grid_efl_object_invalidate(Eo *obj,
                                                     Efl_Ui_Position_Manager_Grid_Data *pd EINA_UNUSED)
 {
-   efl_ui_position_manager_data_access_v1_data_access_set(obj, NULL, NULL, NULL, NULL, NULL, NULL, 0);
+   efl_ui_position_manager_data_access_v1_data_access_set(obj, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0);
 
    efl_invalidate(efl_super(obj, EFL_UI_POSITION_MANAGER_GRID_CLASS));
 }
