@@ -4,12 +4,12 @@
 
 #include <Efl_Ui.h>
 #include "elm_priv.h"
-#include "efl_ui_spotlight_manager_plain.eo.h"
+#include "efl_ui_spotlight_plain_manager.eo.h"
 
 typedef struct _Efl_Ui_Spotlight_Container_Data
 {
    Eina_List *content_list;
-   Eo *page_root, *event;
+   Eo *event;
    struct {
       Eina_Size2D sz;
    } page_spec;
@@ -29,10 +29,13 @@ typedef struct _Efl_Ui_Spotlight_Container_Data
    } transition_done;
    Efl_Ui_Spotlight_Manager *transition;
    Efl_Ui_Spotlight_Indicator *indicator;
+   Eina_Size2D min, max;
    double position;
    Eina_Bool fill_width: 1;
    Eina_Bool fill_height: 1;
    Eina_Bool prevent_transition_interaction : 1;
+   Eina_Bool animation_enabled_internal : 1;
+   Eina_Bool animation_enabled : 1;
 } Efl_Ui_Spotlight_Container_Data;
 
 #define MY_CLASS EFL_UI_SPOTLIGHT_CONTAINER_CLASS
@@ -141,7 +144,7 @@ _transition_event_emission(Eo *obj EINA_UNUSED, Efl_Ui_Spotlight_Container_Data
              pd->show_request.to = -1;
              _transition_end(obj, pd);
           }
-        if (pd->position == pd->show_request.to)
+        if (EINA_DBL_EQ(pd->position, pd->show_request.to))
           {
              //successfully there
              _transition_end(obj, pd);
@@ -155,37 +158,49 @@ _transition_event_emission(Eo *obj EINA_UNUSED, Efl_Ui_Spotlight_Container_Data
 }
 
 static void
-_resize_cb(void *data, const Efl_Event *ev)
+_emit_page_size(Efl_Ui_Spotlight_Container *obj, Efl_Ui_Spotlight_Container_Data *pd)
 {
-   Efl_Ui_Spotlight_Container_Data *pd = data;
    Eina_Size2D sz;
 
-   sz = efl_gfx_entity_size_get(ev->object);
+   sz = efl_gfx_entity_size_get(obj);
 
-   if (pd->fill_width) pd->page_spec.sz.w = sz.w;
-   if (pd->fill_height) pd->page_spec.sz.h = sz.h;
+   if (!pd->fill_width)
+     sz.w = MIN(pd->page_spec.sz.w, sz.w);
+
+   if (!pd->fill_height)
+     sz.h = MIN(pd->page_spec.sz.h, sz.h);
 
    if (pd->transition)
-     efl_ui_spotlight_manager_size_set(pd->transition, pd->page_spec.sz);
+     efl_ui_spotlight_manager_size_set(pd->transition, sz);
 }
 
+static void
+_resize_cb(void *data, const Efl_Event *ev)
+{
+   _emit_page_size(ev->object, data);
+}
+
+static void
+_position_cb(void *data, const Efl_Event *ev EINA_UNUSED)
+{
+   _emit_page_size(ev->object, data);
+}
+
+EFL_CALLBACKS_ARRAY_DEFINE(spotlight_resized,
+  {EFL_GFX_ENTITY_EVENT_SIZE_CHANGED, _resize_cb},
+  {EFL_GFX_ENTITY_EVENT_POSITION_CHANGED, _position_cb},
+)
+
 EOLIAN static Eo *
 _efl_ui_spotlight_container_efl_object_constructor(Eo *obj,
                                      Efl_Ui_Spotlight_Container_Data *pd)
 {
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, NULL);
 
-   if (!elm_widget_theme_klass_get(obj))
-     elm_widget_theme_klass_set(obj, "pager");
-
    obj = efl_constructor(efl_super(obj, MY_CLASS));
 
-   if (elm_widget_theme_object_set(obj, wd->resize_obj,
-                                       elm_widget_theme_klass_get(obj),
-                                       elm_widget_theme_element_get(obj),
-                                       elm_widget_theme_style_get(obj)) == EFL_UI_THEME_APPLY_ERROR_GENERIC)
-     CRI("Failed to set layout!");
-
+   pd->max = EINA_SIZE2D(INT_MAX, INT_MAX);
+   pd->animation_enabled = EINA_TRUE;
    pd->position = -1;
    pd->curr.page = NULL;
    pd->curr.pos = 0.0;
@@ -200,36 +215,33 @@ _efl_ui_spotlight_container_efl_object_constructor(Eo *obj,
 
    elm_widget_can_focus_set(obj, EINA_FALSE);
 
-   pd->page_root = efl_add(EFL_CANVAS_GROUP_CLASS, evas_object_evas_get(obj));
-   efl_content_set(efl_part(obj, "efl.page_root"), pd->page_root);
-
-   efl_event_callback_add(pd->page_root, EFL_GFX_ENTITY_EVENT_SIZE_CHANGED, _resize_cb, pd);
-
-   pd->event = efl_add(EFL_CANVAS_RECTANGLE_CLASS,
-                       evas_object_evas_get(obj));
-   evas_object_color_set(pd->event, 0, 0, 0, 0);
-   evas_object_repeat_events_set(pd->event, EINA_TRUE);
-   efl_content_set(efl_part(obj, "efl.event"), pd->event);
-
+   efl_event_callback_array_add(obj, spotlight_resized(), pd);
    return obj;
 }
 
+static void
+_animated_transition_manager_eval(Eo *obj EINA_UNUSED, Efl_Ui_Spotlight_Container_Data *pd)
+{
+   efl_ui_spotlight_manager_animated_transition_set(pd->transition, pd->animation_enabled_internal && pd->animation_enabled);
+}
+
 EOLIAN static Efl_Object*
-_efl_ui_spotlight_container_efl_object_finalize(Eo *obj, Efl_Ui_Spotlight_Container_Data *pd EINA_UNUSED)
+_efl_ui_spotlight_container_efl_object_finalize(Eo *obj, Efl_Ui_Spotlight_Container_Data *pd)
 {
    Efl_Ui_Spotlight_Manager *manager;
 
    obj = efl_finalize(efl_super(obj, MY_CLASS));
-
+   pd->animation_enabled_internal = EINA_TRUE;
    manager = efl_ui_spotlight_manager_get(obj);
    //set a view manager in case nothing is here
    if (!manager)
      {
-         efl_ui_spotlight_manager_set(obj, efl_new(EFL_UI_SPOTLIGHT_MANAGER_PLAIN_CLASS));
+         efl_ui_spotlight_manager_set(obj, efl_new(EFL_UI_SPOTLIGHT_PLAIN_MANAGER_CLASS));
      }
    else
      {
-        efl_ui_spotlight_manager_animation_enabled_set(manager, EINA_TRUE);
+
+        _animated_transition_manager_eval(obj, pd);
      }
 
    return obj;
@@ -258,9 +270,41 @@ _child_inv(void *data, const Efl_Event *ev)
    _unpack(data, pd, ev->object, index);
 }
 
+#define ADJUST_PRIVATE_MIN_MAX(obj, subobj, pd) \
+  do \
+    { \
+       min = efl_gfx_hint_size_combined_min_get(subobj); \
+       max = efl_gfx_hint_size_combined_max_get(subobj); \
+       pd->min.w = MAX(pd->min.w, min.w); \
+       pd->min.h = MAX(pd->min.h, min.h); \
+       pd->max.w = MIN(pd->max.w, max.w); \
+       pd->max.h = MIN(pd->max.h, max.h); \
+    } \
+  while(0)
+
+#define FLUSH_MIN_MAX(obj, pd) \
+  do \
+    { \
+       efl_gfx_hint_size_restricted_min_set(obj, pd->min); \
+       efl_gfx_hint_size_restricted_max_set(obj, pd->max); \
+    } \
+  while(0)
+
+static void
+_hints_changed_cb(void *data, const Efl_Event *ev EINA_UNUSED)
+{
+   efl_canvas_group_change(data);
+}
+
+EFL_CALLBACKS_ARRAY_DEFINE(children_evt,
+  {EFL_EVENT_INVALIDATE, _child_inv},
+  {EFL_GFX_ENTITY_EVENT_HINTS_CHANGED, _hints_changed_cb}
+)
+
 static Eina_Bool
 _register_child(Eo *obj EINA_UNUSED, Efl_Ui_Spotlight_Container_Data *pd, Efl_Gfx_Entity *subobj)
 {
+   Eina_Size2D min, max;
    EINA_SAFETY_ON_NULL_RETURN_VAL(subobj, EINA_FALSE);
    if (eina_list_data_find(pd->content_list, subobj))
      {
@@ -270,7 +314,10 @@ _register_child(Eo *obj EINA_UNUSED, Efl_Ui_Spotlight_Container_Data *pd, Efl_Gf
    if (!efl_ui_widget_sub_object_add(obj, subobj))
      return EINA_FALSE;
 
-   efl_event_callback_add(subobj, EFL_EVENT_INVALIDATE, _child_inv, obj);
+   efl_event_callback_array_add(subobj, children_evt(), obj);
+
+   ADJUST_PRIVATE_MIN_MAX(obj, subobj, pd);
+   FLUSH_MIN_MAX(obj, pd);
 
    return EINA_TRUE;
 }
@@ -390,10 +437,8 @@ _efl_ui_spotlight_container_efl_pack_linear_pack_index_get(Eo *obj EINA_UNUSED,
    return eina_list_data_idx(pd->content_list, (void *)subobj);
 }
 
-EOLIAN static void
-_efl_ui_spotlight_container_active_element_set(Eo *obj EINA_UNUSED,
-                               Efl_Ui_Spotlight_Container_Data *pd,
-                               Efl_Ui_Widget *new_page)
+static void
+_active_element_set(Eo *obj, Efl_Ui_Spotlight_Container_Data *pd, Efl_Ui_Widget *new_page, Efl_Ui_Spotlight_Manager_Switch_Reason reason)
 {
    int before = -1;
    int index;
@@ -416,7 +461,16 @@ _efl_ui_spotlight_container_active_element_set(Eo *obj EINA_UNUSED,
      }
 
    pd->curr.page = new_page;
-   efl_ui_spotlight_manager_switch_to(pd->transition, before, index);
+   efl_ui_spotlight_manager_switch_to(pd->transition, before, index, reason);
+
+}
+
+EOLIAN static void
+_efl_ui_spotlight_container_active_element_set(Eo *obj EINA_UNUSED,
+                               Efl_Ui_Spotlight_Container_Data *pd,
+                               Efl_Ui_Widget *new_page)
+{
+   _active_element_set(obj, pd, new_page, EFL_UI_SPOTLIGHT_MANAGER_SWITCH_REASON_JUMP);
 }
 
 EOLIAN static Efl_Ui_Widget*
@@ -538,7 +592,8 @@ _unpack(Eo *obj,
        pd->indicator && !pd->transition)
      efl_ui_spotlight_indicator_position_update(pd->indicator, efl_pack_index_get(obj, pd->curr.page));
 
-   efl_event_callback_del(subobj, EFL_EVENT_INVALIDATE, _child_inv, obj);
+   efl_event_callback_array_del(subobj, children_evt(), obj);
+   efl_canvas_group_change(obj);
 }
 
 EOLIAN static Eina_Bool
@@ -600,13 +655,13 @@ EOLIAN static void
 _efl_ui_spotlight_container_spotlight_manager_set(Eo *obj, Efl_Ui_Spotlight_Container_Data *pd, Efl_Ui_Spotlight_Manager *transition)
 {
    if (!transition)
-     pd->transition = efl_add(EFL_UI_SPOTLIGHT_MANAGER_PLAIN_CLASS, obj);
+     pd->transition = efl_add(EFL_UI_SPOTLIGHT_PLAIN_MANAGER_CLASS, obj);
    else
      EINA_SAFETY_ON_FALSE_RETURN(efl_isa(transition, EFL_UI_SPOTLIGHT_MANAGER_CLASS));
 
    if (pd->transition)
      {
-        efl_ui_spotlight_manager_bind(pd->transition, NULL, NULL);
+        efl_ui_spotlight_manager_bind(pd->transition, NULL);
         efl_del(pd->transition);
      }
 
@@ -619,10 +674,10 @@ _efl_ui_spotlight_container_spotlight_manager_set(Eo *obj, Efl_Ui_Spotlight_Cont
         //the api indicates that the caller passes ownership to this function, so we need to unref here
         efl_unref(pd->transition);
         //disable animation when not finalized yet, this help reducing the overhead of scheduling a animation that will not be displayed
-        efl_ui_spotlight_manager_animation_enabled_set(pd->transition, efl_finalized_get(obj));
-        efl_ui_spotlight_manager_bind(pd->transition, obj,
-          pd->page_root);
-        efl_ui_spotlight_manager_size_set(pd->transition, pd->page_spec.sz);
+        _animated_transition_manager_eval(obj, pd);
+        efl_ui_spotlight_manager_animated_transition_set(pd->transition, efl_finalized_get(obj));
+        efl_ui_spotlight_manager_bind(pd->transition, obj);
+        _emit_page_size(obj, pd);
         efl_event_callback_add(pd->transition, EFL_UI_SPOTLIGHT_MANAGER_EVENT_POS_UPDATE, _pos_updated, obj);
      }
 
@@ -631,7 +686,7 @@ _efl_ui_spotlight_container_spotlight_manager_set(Eo *obj, Efl_Ui_Spotlight_Cont
 EOLIAN static Efl_Ui_Spotlight_Manager*
 _efl_ui_spotlight_container_spotlight_manager_get(const Eo *obj EINA_UNUSED, Efl_Ui_Spotlight_Container_Data *pd)
 {
-   if (efl_isa(pd->transition, EFL_UI_SPOTLIGHT_MANAGER_PLAIN_CLASS))
+   if (efl_isa(pd->transition, EFL_UI_SPOTLIGHT_PLAIN_MANAGER_CLASS))
      return NULL;
    else
      return pd->transition;
@@ -642,7 +697,6 @@ _efl_ui_spotlight_container_indicator_set(Eo *obj, Efl_Ui_Spotlight_Container_Da
 {
    if (pd->indicator)
      {
-        efl_ui_spotlight_indicator_bind(pd->indicator, obj);
         efl_del(pd->indicator);
      }
    pd->indicator = indicator;
@@ -653,7 +707,7 @@ _efl_ui_spotlight_container_indicator_set(Eo *obj, Efl_Ui_Spotlight_Container_Da
         //the api indicates that the caller passes ownership to this function, so we need to unref here
         efl_unref(pd->indicator);
         efl_ui_spotlight_indicator_bind(pd->indicator, obj);
-        if (pd->position != -1)
+        if (!EINA_DBL_EQ(pd->position, -1))
           efl_ui_spotlight_indicator_position_update(pd->indicator, pd->position);
      }
 }
@@ -669,16 +723,15 @@ _efl_ui_spotlight_container_push(Eo *obj, Efl_Ui_Spotlight_Container_Data *pd EI
 {
    if (efl_ui_spotlight_active_element_get(obj))
      {
-        if (!efl_pack_before(obj, view, efl_ui_spotlight_active_element_get(obj)))
+        if (!efl_pack_after(obj, view, efl_ui_spotlight_active_element_get(obj)))
           return;
      }
    else
      {
-        if (!efl_pack_begin(obj, view))
+        if (!efl_pack_end(obj, view))
           return;
      }
-
-   efl_ui_spotlight_active_element_set(obj, view);
+   _active_element_set(obj, pd, view, EFL_UI_SPOTLIGHT_MANAGER_SWITCH_REASON_PUSH);
 }
 
 static Eina_Value
@@ -722,9 +775,9 @@ _efl_ui_spotlight_container_pop(Eo *obj, Efl_Ui_Spotlight_Container_Data *pd, Ei
         return efl_loop_future_resolved(obj, v);
      }
 
-   new_index = efl_pack_index_get(obj, efl_ui_spotlight_active_element_get(obj)) + 1;
-   if (new_index >= count)
-     new_index -= 2;
+   new_index = efl_pack_index_get(obj, efl_ui_spotlight_active_element_get(obj)) - 1;
+   if (new_index < 0)
+     new_index += 2;
 
    pd->transition_done.content = content;
    pd->transition_done.transition_done = efl_loop_promise_new(obj);
@@ -733,10 +786,46 @@ _efl_ui_spotlight_container_pop(Eo *obj, Efl_Ui_Spotlight_Container_Data *pd, Ei
    if (del)
      transition_done = eina_future_then(transition_done, _delete_obj, NULL);
 
-   efl_ui_spotlight_active_element_set(obj, efl_pack_content_get(obj, new_index));
+   _active_element_set(obj, pd, efl_pack_content_get(obj, new_index), EFL_UI_SPOTLIGHT_MANAGER_SWITCH_REASON_POP);
 
    return transition_done;
 }
 
+EOLIAN static void
+_efl_ui_spotlight_container_animated_transition_set(Eo *obj, Efl_Ui_Spotlight_Container_Data *pd, Eina_Bool enable)
+{
+   pd->animation_enabled = enable;
+   _animated_transition_manager_eval(obj, pd);
+}
+
+EOLIAN static Eina_Bool
+_efl_ui_spotlight_container_animated_transition_get(const Eo *obj EINA_UNUSED, Efl_Ui_Spotlight_Container_Data *pd)
+{
+   return pd->animation_enabled;
+}
+
+EOLIAN static void
+_efl_ui_spotlight_container_efl_canvas_group_group_calculate(Eo *obj EINA_UNUSED, Efl_Ui_Spotlight_Container_Data *pd)
+{
+   Efl_Ui_Widget *content;
+   Eina_List *n;
+
+   efl_canvas_group_calculate(efl_super(obj, MY_CLASS));
+
+   pd->min = EINA_SIZE2D(0,0);
+   pd->max = EINA_SIZE2D(INT_MAX, INT_MAX);
+
+   EINA_LIST_FOREACH(pd->content_list, n, content)
+     {
+        Eina_Size2D min, max;
+
+        min = efl_gfx_hint_size_combined_min_get(content);
+        max = efl_gfx_hint_size_combined_max_get(content);
+
+        ADJUST_PRIVATE_MIN_MAX(obj, content, pd);
+     }
+   FLUSH_MIN_MAX(obj, pd);
+}
+
 
 #include "efl_ui_spotlight_container.eo.c"
