@@ -5,7 +5,7 @@
 #include "Elementary.h"
 
 #include "elm_code_private.h"
-#include "elm_code_widget_legacy.eo.h"
+#include "elm_code_widget_legacy_eo.h"
 
 #define _ELM_CODE_DIFF_WIDGET_LEFT "diffwidgetleft"
 #define _ELM_CODE_DIFF_WIDGET_RIGHT "diffwidgetright"
@@ -96,7 +96,7 @@ elm_code_diff_widget_add(Evas_Object *parent, Elm_Code *code)
    // left side of diff
    wcode1 = elm_code_create();
    elm_code_parser_standard_add(wcode1, ELM_CODE_PARSER_STANDARD_DIFF);
-   widget_left = elm_legacy_add(ELM_CODE_WIDGET_LEGACY_CLASS, parent, elm_obj_code_widget_code_set(efl_added, wcode1));
+   widget_left = elm_legacy_add(ELM_CODE_WIDGET_LEGACY_CLASS, parent, efl_ui_code_widget_code_set(efl_added, wcode1));
 
    evas_object_size_hint_weight_set(widget_left, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
    evas_object_size_hint_align_set(widget_left, EVAS_HINT_FILL, EVAS_HINT_FILL);
@@ -107,7 +107,7 @@ elm_code_diff_widget_add(Evas_Object *parent, Elm_Code *code)
    // right side of diff
    wcode2 = elm_code_create();
    elm_code_parser_standard_add(wcode2, ELM_CODE_PARSER_STANDARD_DIFF);
-   widget_right = elm_legacy_add(ELM_CODE_WIDGET_LEGACY_CLASS, parent, elm_obj_code_widget_code_set(efl_added, wcode2));
+   widget_right = elm_legacy_add(ELM_CODE_WIDGET_LEGACY_CLASS, parent, efl_ui_code_widget_code_set(efl_added, wcode2));
 
    evas_object_size_hint_weight_set(widget_right, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
    evas_object_size_hint_align_set(widget_right, EVAS_HINT_FILL, EVAS_HINT_FILL);
@@ -125,8 +125,8 @@ elm_code_diff_widget_font_set(Evas_Object *widget, const char *name, int size)
    Elm_Code_Widget *child;
 
    child = (Elm_Code_Widget *) evas_object_data_get(widget, _ELM_CODE_DIFF_WIDGET_LEFT);
-   elm_obj_code_widget_font_set(child, name, size);
+   efl_ui_code_widget_font_set(child, name, size);
    child = (Elm_Code_Widget *) evas_object_data_get(widget, _ELM_CODE_DIFF_WIDGET_RIGHT);
-   elm_obj_code_widget_font_set(child, name, size);
+   efl_ui_code_widget_font_set(child, name, size);
 }
 
