@@ -49,7 +49,7 @@ struct _Elm_Toolbar_Data
    Elm_Object_Select_Mode                select_mode;
    Ecore_Timer                          *long_timer;
    Ecore_Job                            *resize_job;
-   Efl_Ui_Dir                            dir;
+   Efl_Ui_Layout_Orientation             dir;
 
    Eina_Bool                             long_press : 1;
    Eina_Bool                             homogeneous : 1;
