@@ -9,7 +9,8 @@ void
 database_event_del(Eolian_Event *event)
 {
    if (!event) return;
-   if (event->name) eina_stringshare_del(event->name);
+   eina_stringshare_del(event->base.file);
+   eina_stringshare_del(event->base.name);
    database_type_del(event->type);
    database_doc_del(event->doc);
    free(event);
