@@ -10,7 +10,7 @@ typedef struct _Efl_Canvas_Animation_Data
    double                    start_delay_time;
 
    Efl_Canvas_Animation_Repeat_Mode repeat_mode;
-   int                       repeat_count;
+   int                       play_count;
 
    Efl_Interpolator         *interpolator;
 
@@ -25,4 +25,4 @@ typedef struct _Efl_Canvas_Animation_Data
 
 #define FINAL_STATE_IS_REVERSE(anim) \
    ((efl_animation_repeat_mode_get(anim) == EFL_CANVAS_ANIMATION_REPEAT_MODE_REVERSE) && \
-    (efl_animation_repeat_count_get(anim) & 1))
+    (efl_animation_play_count_get(anim) & 1))
