@@ -206,9 +206,11 @@ EVAS_EINA_STATIC_MODULE_DEFINE(image_loader, heif);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_loader, ico);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_loader, jpeg);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_loader, jp2k);
+EVAS_EINA_STATIC_MODULE_DEFINE(image_loader, jxl);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_loader, pmaps);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_loader, png);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_loader, psd);
+EVAS_EINA_STATIC_MODULE_DEFINE(image_loader, qoi);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_loader, svg);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_loader, tga);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_loader, tiff);
@@ -227,7 +229,9 @@ EVAS_EINA_STATIC_MODULE_DEFINE(vg_saver, svg);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_saver, avif);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_saver, eet);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_saver, jpeg);
+EVAS_EINA_STATIC_MODULE_DEFINE(image_saver, jxl);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_saver, png);
+EVAS_EINA_STATIC_MODULE_DEFINE(image_saver, qoi);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_saver, tiff);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_saver, webp);
 EVAS_EINA_STATIC_MODULE_DEFINE(image_saver, tgv);
@@ -320,6 +324,9 @@ static const struct {
 #ifdef EVAS_STATIC_BUILD_JP2K
   EVAS_EINA_STATIC_MODULE_USE(image_loader, jp2k),
 #endif
+#ifdef EVAS_STATIC_BUILD_JXL
+  EVAS_EINA_STATIC_MODULE_USE(image_loader, jxl),
+#endif
 #ifdef EVAS_STATIC_BUILD_PMAPS
   EVAS_EINA_STATIC_MODULE_USE(image_loader, pmaps),
 #endif
@@ -329,6 +336,9 @@ static const struct {
 #ifdef EVAS_STATIC_BUILD_PSD
   EVAS_EINA_STATIC_MODULE_USE(image_loader, psd),
 #endif
+#ifdef EVAS_STATIC_BUILD_QOI
+  EVAS_EINA_STATIC_MODULE_USE(image_loader, qoi),
+#endif
 #ifdef EVAS_STATIC_BUILD_SVG
   EVAS_EINA_STATIC_MODULE_USE(image_loader, svg),
 #endif
@@ -369,9 +379,15 @@ static const struct {
 #ifdef EVAS_STATIC_BUILD_JPEG
   EVAS_EINA_STATIC_MODULE_USE(image_saver, jpeg),
 #endif
+#ifdef EVAS_STATIC_BUILD_JXL
+  EVAS_EINA_STATIC_MODULE_USE(image_saver, jxl),
+#endif
 #ifdef EVAS_STATIC_BUILD_PNG
   EVAS_EINA_STATIC_MODULE_USE(image_saver, png),
 #endif
+#ifdef EVAS_STATIC_BUILD_QOI
+  EVAS_EINA_STATIC_MODULE_USE(image_saver, qoi),
+#endif
 #ifdef EVAS_STATIC_BUILD_TIFF
   EVAS_EINA_STATIC_MODULE_USE(image_saver, tiff),
 #endif
