@@ -5,9 +5,6 @@
 #include <sys/time.h>
 #include <sys/utsname.h>
 
-#ifdef EVAS_CSERVE2
-#include "evas_cs2_private.h"
-#endif
 #include "evas_common_private.h"
 #include "evas_macros.h"
 #include "evas_xlib_outbuf.h"
@@ -177,13 +174,6 @@ evas_software_xlib_outbuf_free(Outbuf *buf)
         im = buf->priv.pending_writes->data;
         buf->priv.pending_writes = eina_list_remove_list(buf->priv.pending_writes, buf->priv.pending_writes);
         obr = im->extended_info;
-#ifdef EVAS_CSERVE2
-        if (evas_cserve2_use_get())
-          {
-             evas_cache2_image_close(&im->cache_entry);
-          }
-        else
-#endif
         evas_cache_image_drop(&im->cache_entry);
         if (obr->xob) _unfind_xob(obr->xob, 0);
         if (obr->mxob) _unfind_xob(obr->mxob, 0);
@@ -467,16 +457,6 @@ evas_software_xlib_outbuf_new_region_for_update(Outbuf *buf, int x, int y, int w
                   eina_spinlock_release(&(buf->priv.lock));
                   return NULL;
                }
-#ifdef EVAS_CSERVE2
-             if (evas_cserve2_use_get())
-               {
-                  im = (RGBA_Image *)evas_cache2_image_data(evas_common_image_cache2_get(),
-                                                            buf->w, buf->h,
-                                                            (DATA32 *)evas_software_xlib_x_output_buffer_data(obr->xob, &bpl),
-                                                            alpha, EVAS_COLORSPACE_ARGB8888);
-               }
-             else
-#endif
              im = (RGBA_Image *)evas_cache_image_data(evas_common_image_cache_get(),
                                                       buf->w, buf->h,
                                                       (DATA32 *)evas_software_xlib_x_output_buffer_data(obr->xob, &bpl),
@@ -499,11 +479,6 @@ evas_software_xlib_outbuf_new_region_for_update(Outbuf *buf, int x, int y, int w
           }
         else
           {
-#ifdef EVAS_CSERVE2
-             if (evas_cserve2_use_get())
-               im = (RGBA_Image *)evas_cache2_image_empty(evas_common_image_cache2_get());
-             else
-#endif
              im = (RGBA_Image *)evas_cache_image_empty(evas_common_image_cache_get());
              if (!im)
                {
@@ -512,11 +487,6 @@ evas_software_xlib_outbuf_new_region_for_update(Outbuf *buf, int x, int y, int w
                   return NULL;
                }
              im->cache_entry.flags.alpha |= alpha ? 1 : 0;
-#ifdef EVAS_CSERVE2
-             if (evas_cserve2_use_get())
-               evas_cache2_image_surface_alloc(&im->cache_entry, buf->w, buf->h);
-             else
-#endif
              evas_cache_image_surface_alloc(&im->cache_entry, buf->w, buf->h);
              im->extended_info = obr;
              if ((buf->rot == 0) || (buf->rot == 180))
@@ -529,13 +499,6 @@ evas_software_xlib_outbuf_new_region_for_update(Outbuf *buf, int x, int y, int w
                                                                     NULL);
                   if (!obr->xob)
                     {
-#ifdef EVAS_CSERVE2
-                       if (evas_cserve2_use_get())
-                         {
-                            evas_cache2_image_close(&im->cache_entry);
-                         }
-                       else
-#endif
                        evas_cache_image_drop(&im->cache_entry);
                        free(obr);
                        eina_spinlock_release(&(buf->priv.lock));
@@ -558,13 +521,6 @@ evas_software_xlib_outbuf_new_region_for_update(Outbuf *buf, int x, int y, int w
                                                                     NULL);
                   if (!obr->xob)
                     {
-#ifdef EVAS_CSERVE2
-                       if (evas_cserve2_use_get())
-                         {
-                            evas_cache2_image_close(&im->cache_entry);
-                         }
-                       else
-#endif
                        evas_cache_image_drop(&im->cache_entry);
                        free(obr);
                        eina_spinlock_release(&(buf->priv.lock));
@@ -633,14 +589,6 @@ evas_software_xlib_outbuf_new_region_for_update(Outbuf *buf, int x, int y, int w
              eina_spinlock_release(&(buf->priv.lock));
              return NULL;
           }
-#ifdef EVAS_CSERVE2
-        if (evas_cserve2_use_get())
-          im = (RGBA_Image *)evas_cache2_image_data(evas_common_image_cache2_get(),
-                                                    w, h,
-                                                    (DATA32 *)evas_software_xlib_x_output_buffer_data(obr->xob, &bpl),
-                                                    alpha, EVAS_COLORSPACE_ARGB8888);
-        else
-#endif
         im = (RGBA_Image *)evas_cache_image_data(evas_common_image_cache_get(),
                                                  w, h,
                                                  (DATA32 *)evas_software_xlib_x_output_buffer_data(obr->xob, &bpl),
@@ -662,11 +610,6 @@ evas_software_xlib_outbuf_new_region_for_update(Outbuf *buf, int x, int y, int w
      }
    else
      {
-#ifdef EVAS_CSERVE2
-        if (evas_cserve2_use_get())
-          im = (RGBA_Image *)evas_cache2_image_empty(evas_common_image_cache2_get());
-        else
-#endif
         im = (RGBA_Image *)evas_cache_image_empty(evas_common_image_cache_get());
         if (!im)
           {
@@ -677,11 +620,6 @@ evas_software_xlib_outbuf_new_region_for_update(Outbuf *buf, int x, int y, int w
         im->cache_entry.w = w;
         im->cache_entry.h = h;
         im->cache_entry.flags.alpha |= alpha ? 1 : 0;
-#ifdef EVAS_CSERVE2
-        if (evas_cserve2_use_get())
-          evas_cache2_image_surface_alloc(&im->cache_entry, w, h);
-        else
-#endif
         evas_cache_image_surface_alloc(&im->cache_entry, w, h);
         im->extended_info = obr;
         if ((buf->rot == 0) || (buf->rot == 180))
@@ -694,13 +632,6 @@ evas_software_xlib_outbuf_new_region_for_update(Outbuf *buf, int x, int y, int w
                                   NULL);
              if (!obr->xob)
                {
-#ifdef EVAS_CSERVE2
-                  if (evas_cserve2_use_get())
-                    {
-                       evas_cache2_image_close(&im->cache_entry);
-                    }
-                  else
-#endif
                   evas_cache_image_drop(&im->cache_entry);
                   free(obr);
                   eina_spinlock_release(&(buf->priv.lock));
@@ -723,13 +654,6 @@ evas_software_xlib_outbuf_new_region_for_update(Outbuf *buf, int x, int y, int w
                                   NULL);
              if (!obr->xob)
                {
-#ifdef EVAS_CSERVE2
-                  if (evas_cserve2_use_get())
-                    {
-                       evas_cache2_image_close(&im->cache_entry);
-                    }
-                  else
-#endif
                   evas_cache_image_drop(&im->cache_entry);
                   free(obr);
                   eina_spinlock_release(&(buf->priv.lock));
@@ -861,13 +785,6 @@ evas_software_xlib_outbuf_flush(Outbuf *buf, Tilebuf_Rect *surface_damage EINA_U
                eina_list_remove_list(buf->priv.prev_pending_writes,
                                      buf->priv.prev_pending_writes);
              obr = im->extended_info;
-#ifdef EVAS_CSERVE2
-             if (evas_cserve2_use_get())
-               {
-                  evas_cache2_image_close(&im->cache_entry);
-               }
-             else
-#endif
              evas_cache_image_drop(&im->cache_entry);
              if (obr->xob) _unfind_xob(obr->xob, 0);
              if (obr->mxob) _unfind_xob(obr->mxob, 0);
@@ -905,24 +822,10 @@ evas_software_xlib_outbuf_flush(Outbuf *buf, Tilebuf_Rect *surface_damage EINA_U
              im = eina_list_data_get(buf->priv.pending_writes);
              buf->priv.pending_writes = eina_list_remove_list(buf->priv.pending_writes, buf->priv.pending_writes);
              obr = im->extended_info;
-#ifdef EVAS_CSERVE2
-             if (evas_cserve2_use_get())
-               {
-                  evas_cache2_image_close(&im->cache_entry);
-               }
-             else
-#endif
              evas_cache_image_drop(&im->cache_entry);
              if (obr->xob) _unfind_xob(obr->xob, 0);
              if (obr->mxob) _unfind_xob(obr->mxob, 0);
              free(obr);
-#ifdef EVAS_CSERVE2
-             if (evas_cserve2_use_get())
-               {
-                  evas_cache2_image_close(&im->cache_entry);
-               }
-             else
-#endif
              evas_cache_image_drop(&im->cache_entry);
           }
 #endif
@@ -956,13 +859,6 @@ evas_software_xlib_outbuf_idle_flush(Outbuf *buf)
              SHMPOOL_UNLOCK();
           }
         free(obr);
-#ifdef EVAS_CSERVE2
-        if (evas_cserve2_use_get())
-          {
-             evas_cache2_image_close(&im->cache_entry);
-          }
-        else
-#endif
         evas_cache_image_drop(&im->cache_entry);
      }
    else
@@ -978,13 +874,6 @@ evas_software_xlib_outbuf_idle_flush(Outbuf *buf)
                eina_list_remove_list(buf->priv.prev_pending_writes,
                                      buf->priv.prev_pending_writes);
              obr = im->extended_info;
-#ifdef EVAS_CSERVE2
-             if (evas_cserve2_use_get())
-               {
-                  evas_cache2_image_close(&im->cache_entry);
-               }
-             else
-#endif
              evas_cache_image_drop(&im->cache_entry);
              if (obr->xob) _unfind_xob(obr->xob, 0);
              if (obr->mxob) _unfind_xob(obr->mxob, 0);
