@@ -4,7 +4,7 @@
  * Line breaking in a Unicode sequence.  Designed to be used in a
  * generic text renderer.
  *
- * Copyright (C) 2008-2016 Wu Yongwei <wuyongwei at gmail dot com>
+ * Copyright (C) 2008-2018 Wu Yongwei <wuyongwei at gmail dot com>
  * Copyright (C) 2013 Petr Filipsky <philodej at gmail dot com>
  *
  * This software is provided 'as-is', without any express or implied
@@ -31,9 +31,9 @@
  * Unicode 5.0.0:
  *      <URL:http://www.unicode.org/reports/tr14/tr14-19.html>
  *
- * This library has been updated according to Revision 37, for
- * Unicode 9.0.0:
- *      <URL:http://www.unicode.org/reports/tr14/tr14-37.html>
+ * This library has been updated according to Revision 43, for
+ * Unicode 12.0.0:
+ *      <URL:http://www.unicode.org/reports/tr14/tr14-43.html>
  *
  * The Unicode Terms of Use are available at
  *      <URL:http://www.unicode.org/copyright.html>
@@ -52,8 +52,8 @@
 #include "unibreakdef.h"
 
 /**
- * Line break classes.  This is a direct mapping of Table 1 of Unicode
- * Standard Annex 14, Revision 26.
+ * Line break classes.  This is a mapping of Table 1 of Unicode
+ * Standard Annex 14.
  */
 enum LineBreakClass
 {
@@ -95,7 +95,7 @@ enum LineBreakClass
     LBP_ZWJ,        /**< Zero width joiner */
 
     /* The following break class is treated in the pair table, but it is
-     * not part of Table 2 of UAX #14. */
+     * not part of Table 2 of UAX #14-37. */
     LBP_CB,         /**< Contingent break */
 
     /* The following break classes are not treated in the pair table */
@@ -117,8 +117,8 @@ enum LineBreakClass
  */
 struct LineBreakProperties
 {
-    utf32_t start;              /**< Starting coding point */
-    utf32_t end;                /**< End coding point */
+    utf32_t start;              /**< Start codepoint */
+    utf32_t end;                /**< End codepoint, inclusive */
     enum LineBreakClass prop;   /**< The line breaking property */
 };
 
@@ -140,11 +140,14 @@ struct LineBreakPropertiesLang
 struct LineBreakContext
 {
     const char *lang;               /**< Language name */
-    const struct LineBreakProperties *lbpLang;/**< Pointer to LineBreakProperties */
+    const struct LineBreakProperties *lbpLang; /**< Pointer to
+                                                    LineBreakProperties */
     enum LineBreakClass lbcCur;     /**< Breaking class of current codepoint */
     enum LineBreakClass lbcNew;     /**< Breaking class of next codepoint */
     enum LineBreakClass lbcLast;    /**< Breaking class of last codepoint */
-    int fLb21aHebrew;               /**< Flag for Hebrew letters (LB21a) */
+    bool fLb8aZwj;                  /**< Flag for ZWJ (LB8a) */
+    bool fLb10LeadSpace;            /**< Flag for leading space (LB10) */
+    bool fLb21aHebrew;              /**< Flag for Hebrew letters (LB21a) */
     int cLb30aRI;                   /**< Count of RI characters (LB30a) */
 };
 
