@@ -5,6 +5,10 @@
 #include <stdio.h>
 #include <unistd.h>
 
+#ifdef _WIN32
+# include <evil_private.h> /* pipe */
+#endif
+
 #include <Eina.h>
 #include <Ecore.h>
 
@@ -35,6 +39,8 @@ EFL_START_TEST(ecore_test_ecore_main_loop)
    timer = ecore_timer_add(0.0, _quit_cb, &did);
    fail_if(timer == NULL);
 
+   /* ensure that this does not auto-cancel main loop */
+   ecore_main_loop_quit();
    ecore_main_loop_begin();
 
    fail_if(did == EINA_FALSE);
@@ -455,9 +461,16 @@ EFL_START_TEST(ecore_test_ecore_app)
    int argc_out = 0;
    char **argv_out = NULL;
 
+   int pargc;
+   char **pargv;
+
+   ecore_app_args_get(&pargc, &pargv);
+
    ecore_app_args_set(argc_in, argv_in);
    ecore_app_args_get(&argc_out, &argv_out);
 
+   ecore_app_args_set(pargc, (const char**)pargv);
+
    fail_if(argc_in != argc_out);
    int i;
    for (i = 0; i < argc_out; i++)
