@@ -6,17 +6,10 @@
 
 #include "eet_suite.h"
 
-START_TEST(_eet_test_init)
+EFL_START_TEST(_eet_test_init)
 {
-   int ret;
-
-   ret = eet_init();
-   fail_if(ret != 1);
-
-   ret = eet_shutdown();
-   fail_if(ret != 0);
 }
-END_TEST
+EFL_END_TEST
 
 void eet_test_init(TCase *tc)
 {
