@@ -6,7 +6,7 @@ typedef struct
    int cb_count;
 } Simple_Public_Data;
 
-EAPI void simple_a_set(Eo *obj, int a);
+void simple_a_set(Eo *obj, int a);
 
 extern const Efl_Event_Description _EV_A_CHANGED;
 #define EV_A_CHANGED (&(_EV_A_CHANGED))
